@@ -1,8 +1,9 @@
 /******************************************************************
  *
- * @(#)$Id: db2APRS.c,v 1.2 2004/06/10 23:51:28 we7u Exp $
+ * @(#)$Id: db2APRS.c,v 1.7 2006/10/26 15:52:42 we7u Exp $
  *
  * Copyright (C) 2004 Bruce Bennett <bruts@adelphia.net>
+ * Portions Copyright (C) 2004-2006 The Xastir Group
  *
  * (see the files README and COPYING for more details)
  *
@@ -57,14 +58,17 @@
 #define TMPLEN 128      /* max length of CGI */
 #define BUFLEN 32       /* max length of hostname:port */
 
-#define VALID_WINDDIR   0x01
-#define VALID_WINDSPD   0x02
-#define VALID_WINDGST   0x04
-#define VALID_TEMP      0x08
-#define VALID_RAIN1HR   0x10
-#define VALID_RAIN24H   0x20
-#define VALID_HUMIDITY  0x40
-#define VALID_AIRPRESS  0x80
+#define POLL_INTERVAL	90		// default polling interval
+
+#define VALID_WINDDIR   0x001
+#define VALID_WINDSPD   0x002
+#define VALID_WINDGST   0x004
+#define VALID_TEMP      0x008
+#define VALID_RAIN      0x010
+#define VALID_RAIN24H   0x020
+#define VALID_HUMIDITY  0x040
+#define VALID_AIRPRESS  0x080
+#define VALID_RAINDAY	0x100
 
 #define MTPS2MPH        2.2369
 #define DEGC2DEGF       1.8
@@ -74,7 +78,7 @@
 #define OUTDOOR_SENSOR  1
 
     //---From the static table "mfield", which really should be dynamically read here---
-    //			(but then I couldn't use a switch statement)
+    //     (but then I couldn't use a switch statement)
 
 #define TEMPERATURE         0
 #define TEMPERATURE_MIN     1
@@ -125,6 +129,8 @@ MYSQL_RES   *result;
 MYSQL_ROW   row;
 
 char last_timestamp[20];
+char last_datetime[20];
+char death_msg[120];
 
 int debug_level;
 
@@ -141,8 +147,8 @@ void usage(int ret)
 {
     if (query)
         printf("Content-type: text/plain\nStatus: 200\n\n");
-	printf("usage: %s [options] \n",progname);
-	printf("VERSION: %s\n",VERSION);
+    printf("usage: %s [options] \n",progname);
+    printf("VERSION: %s\n",VERSION);
     printf("  -h    --help                      show this help and exit\n");
     printf("  -v    --verbose                   debugging info --> stderr\n");
     printf("  -c    --cport [port#]             IP port for data output\n");
@@ -152,6 +158,8 @@ void usage(int ret)
     printf("  -b    --database [database]       database name - default meteo\n");
     printf("  -n    --nodaemon                  do not run as daemon\n");
     printf("  -r    --repeat                    keep running\n");
+    printf("  -i    --interval [seconds]        polling interval\n");
+    printf("  -m    --metric                    data base is in metric units\n");
     printf("options may be uniquely abbreviated; units are as defined in APRS\n"); 
     printf("Specification 1.0.1 for positionless weather data (English/hPa).\n");
     exit(ret);
@@ -168,12 +176,14 @@ void usage(int ret)
 *******************************************************************/
 
 int APRS_str(char *APRS_buf, 
+            char *datetime,
             double winddir,
             double windspeed,				
             double windgust,
             double temp,
             double rain1hr,
-            double rain24h,
+            double rain24hr,
+            double rainday,
             double humidity,
             double airpressure,
             unsigned int valid_data_flgs,
@@ -186,9 +196,12 @@ int APRS_str(char *APRS_buf,
     if (APRS_buf == NULL) {
         if (debug_level & 1)
             fprintf(stderr,"err: Null string buffer for APRS string.\n");
-        return 0;  //  Ooo!!  *****Nasty Bad Exit Point Here****
+        return -1;  //  Ooo!!  *****Nasty Bad Exit Point Here****
 
     }
+//  timestamp first
+    sprintf(APRS_buf, "_%s",datetime);
+//
     if(valid_data_flgs & VALID_WINDDIR) {
         intval = (winddir + 0.5); // rounding to whole degrees
         if (intval > 360) {
@@ -203,15 +216,16 @@ int APRS_str(char *APRS_buf,
 
         } 
         else {
-            sprintf(APRS_buf, "c%0.3d", intval);
+        sprintf(pbuf, "c%0.3d", intval);
         }
-    } 
+    }
     else {
         if (debug_level & 1)
             fprintf(stderr,"info: Wind direction flagged as invalid\n");
-        sprintf(APRS_buf, "c...");
+        sprintf(pbuf, "c...");
 
     }
+    strcat(APRS_buf,pbuf);
 
     if(valid_data_flgs & VALID_WINDSPD) {
         if (Metric_Data)
@@ -223,17 +237,17 @@ int APRS_str(char *APRS_buf,
                 fprintf(stderr,"err: Wind speed > 600 MPH\n");
             sprintf(pbuf, "s...");
 
-        } 
+        }
         else if (intval < 0) {
             if (debug_level & 1)
                 fprintf(stderr,"err: Wind speed negative\n");
             sprintf(pbuf, "s...");
 
-		} 
-        else {
-				sprintf(pbuf, "s%0.3d", intval);
         }
-    } 
+        else {
+            sprintf(pbuf, "s%0.3d", intval);
+        }
+    }
     else {
         if (debug_level & 1)
             fprintf(stderr,"info: Wind speed flagged as invalid\n");
@@ -252,7 +266,7 @@ int APRS_str(char *APRS_buf,
                 fprintf(stderr,"err: Wind gust > 600 MPH\n");
             sprintf(pbuf, "g...");
 
-        } 
+        }
         else if (intval < 0) {
             if (debug_level & 1)
                 fprintf(stderr,"err: Wind speed negative\n");
@@ -263,14 +277,14 @@ int APRS_str(char *APRS_buf,
             sprintf(pbuf, "g%0.3d", intval);
         }
 
-    } 
+    }
     else {
-	    if (debug_level & 1)
+        if (debug_level & 1)
             fprintf(stderr,"info: Wind speed flagged as invalid\n");
         sprintf(pbuf, "g...");
 
     }
-	strcat(APRS_buf,pbuf);
+    strcat(APRS_buf,pbuf);
 
     if(valid_data_flgs & VALID_TEMP) {
         if (Metric_Data)
@@ -281,29 +295,25 @@ int APRS_str(char *APRS_buf,
             if (debug_level & 1)
                 fprintf(stderr,"err: Temperature > 200 Deg F\n");
             sprintf(pbuf, "t...");
-
-        } 
+        }
         else if (intval < -99) {
             if (debug_level & 1)
                 fprintf(stderr,"err: Temperature < -99 Deg F\n");
             sprintf(pbuf, "t...");
-
-        } 
+        }
         else {
             if (intval < 0) sprintf(pbuf,"t%0.2d",intval);
             else sprintf(pbuf, "t%0.3d", intval);
         }
-
-    } 
+    }
     else {
         if (debug_level & 1)
             fprintf(stderr,"info: Temperature flagged as invalid\n");
         sprintf(pbuf, "t...");
-
     }
     strcat(APRS_buf,pbuf);
 
-    if(valid_data_flgs & VALID_RAIN1HR) {
+    if(valid_data_flgs & VALID_RAIN) {
         if (Metric_Data)
             intval = ((rain1hr)*MM2IN100TH + 0.5); // converting & rounding to whole 1/100 inch
         else
@@ -312,20 +322,18 @@ int APRS_str(char *APRS_buf,
             if (debug_level & 1)
                 fprintf(stderr,"err: Rainfall/Hr > 9.99 inch\n");
             sprintf(pbuf, "\0\0\0\0");
-
-        } 
+        }
         else if (intval < -99) {
             if (debug_level & 1)
                 fprintf(stderr,"err: Rainfall/Hr negative\n");
             sprintf(pbuf, "\0\0\0\0");
-
-        } 
+        }
         else {
             sprintf(pbuf, "r%0.3d", intval);
         }
-    } 
+    }
     else {
-	
+
         if (debug_level & 1)
             fprintf(stderr,"info: Rainfall/Hr flagged as invalid\n");
         sprintf(pbuf, "\0\0\0\0");
@@ -335,30 +343,55 @@ int APRS_str(char *APRS_buf,
 
     if(valid_data_flgs & VALID_RAIN24H) {
         if (Metric_Data)
-            intval = ((rain24h)*MM2IN100TH + 0.5); // converting & rounding to whole 1/100 inch
+            intval = ((rain24hr)*MM2IN100TH + 0.5); // converting & rounding to whole 1/100 inch
         else
-            intval = (rain24h*100.0 + 0.5); // rounding to whole 1/100 inch
+            intval = (rain24hr*100.0 + 0.5); // rounding to whole 1/100 inch
         if (intval > 999) { // Can't handle greater than 9.99 inches of rain in 24 hours
             if (debug_level & 1)
                 fprintf(stderr,"err: Rainfall/24Hr > 9.99 inch - reporting 9.99 inches\n");
             sprintf(pbuf, "p999");
 
-        } 
+        }
         else if (intval < -99) {
             if (debug_level & 1)
                 fprintf(stderr,"err: Rainfall/Hr negative\n");
             sprintf(pbuf, "\0\0\0\0");
 
-        } 
+        }
         else {
             sprintf(pbuf, "p%0.3d", intval);
         }
-    } 
+    }
     else {
         if (debug_level & 1)
             fprintf(stderr,"info: Rainfall/24Hr flagged as invalid\n");
         sprintf(pbuf, "\0\0\0\0");
+    }
+    strcat(APRS_buf,pbuf);
 
+    if(valid_data_flgs & VALID_RAINDAY) {
+        if (Metric_Data)
+            intval = ((rainday)*MM2IN100TH + 0.5); // converting & rounding to whole 1/100 inch
+        else
+            intval = (rainday*100.0 + 0.5); // rounding to whole 1/100 inch
+        if (intval > 999) { // Can't handle greater than 9.99 inches of rain per day
+            if (debug_level & 1)
+                fprintf(stderr,"err: Rainfall/day > 9.99 inch - reporting 9.99 inches\n");
+            sprintf(pbuf, "P999");
+        }
+        else if (intval < -99) {
+            if (debug_level & 1)
+                fprintf(stderr,"err: Rainfall/day negative\n");
+            sprintf(pbuf, "\0\0\0\0");
+        }
+        else {
+            sprintf(pbuf, "P%0.3d", intval);
+        }
+    }
+    else {
+        if (debug_level & 1)
+            fprintf(stderr,"info: Rainfall/day flagged as invalid\n");
+        sprintf(pbuf, "\0\0\0\0");
     }
     strcat(APRS_buf,pbuf);
 
@@ -369,18 +402,18 @@ int APRS_str(char *APRS_buf,
                 fprintf(stderr,"err: Humidity reported > 100%\n");
             sprintf(pbuf, "\0\0\0\0");
 
-		} 
+        }
         else if (intval < 1) {
             if (debug_level & 1)
                 fprintf(stderr,"err: Humidity reported < 1%\n");
             sprintf(pbuf, "\0\0\0\0");
 
-        } 
+        }
         else {
             if (intval == 100) intval = 0;  // Report 100% as 'h00'
             sprintf(pbuf, "h%0.2d", intval);
         }
-    } 
+    }
     else {
         if (debug_level & 1)
             fprintf(stderr,"info: Humidity flagged as invalid\n");
@@ -398,8 +431,7 @@ int APRS_str(char *APRS_buf,
             if (debug_level & 1)
                 fprintf(stderr,"err: Air Pressure reported > 2 Atmospheres%\n");
                 sprintf(pbuf, "\0\0\0\0");
-
-        } 
+        }
         else if (intval < 0) {
             if (debug_level & 1)
                 fprintf(stderr,"err: Air Pressure reported negative%\n");
@@ -408,8 +440,8 @@ int APRS_str(char *APRS_buf,
         } 
         else {
             sprintf(pbuf, "b%0.5d", intval);
-		}
-	} else {
+        }
+    } else {
         if (debug_level & 1)
             fprintf(stderr,"info: Air Pressure flagged as invalid\n");
         sprintf(pbuf, "\0\0\0\0");
@@ -438,104 +470,120 @@ int Get_Latest_WX( double *winddir,
                 double *windgust,
                 double *temp,
                 double *rain1hr,
-                double *rain24h,
+                double *rain24hr,
+                double *rainday,
                 double *humidity,
                 double *airpressure,
-                unsigned int *valid_data_flgs,
-                int *Metric_Data)
-
+                unsigned int *valid_data_flgs)
 {
-
-    char latest_timestamp[20];
-    char query_buffer[160];
+    long last_hour_timestamp;
+    long int last_24_timestamp;
+    long int last_day_timestamp;
+    char query_buffer[240];
     int nrows, row_cnt, item_count;
+    int found_sensor;
+    long local_offset;  // could be as big as 12 hrs times 3600 seconds...
 
-		
     // Find latest, see if it's new to us
     // --new to us is a simple timestamp follower, so upon startup
     // it will always read one set of data, assuming any exists
 
     if (mysql_query(&mysql, "SELECT MAX(timekey) from sdata")) {
-        if (debug_level & 1)
-            fprintf(stderr,"err: Latest timestamp query failed - exiting: %s\n", mysql_error(&mysql));
-        return 0;
+        sprintf(death_msg,"err: Latest timestamp query failed - exiting: %s\n", mysql_error(&mysql));
+        if (debug_level & 1){
+            fprintf(stderr,"%s",death_msg);
+        }
+        return -1;
     }
-	
-    if (!(result = mysql_store_result(&mysql))) {
-        if (debug_level & 1)
-            fprintf(stderr,"err: Latest timestamp query failed - exiting: %s\n", mysql_error(&mysql));
-        return 0;
+ 
+     if (!(result = mysql_store_result(&mysql))) {
+         sprintf(death_msg,"err: Latest timestamp query failed - exiting: %s\n", mysql_error(&mysql));
+         if (debug_level & 1){
+             fprintf(stderr,"%s",death_msg);
+         }
+         return -1;
     }
-	
+
     if (mysql_num_rows(result) != 1 ) {
-        if (debug_level & 1)
-            fprintf(stderr,"err: Latest timestamp query failed - exiting: number of results %d\n",
+        sprintf(death_msg,"err: Latest timestamp query failed - exiting: number of results %d\n",
                 mysql_num_rows(result));
+        if (debug_level & 1){
+            fprintf(stderr,"%s",death_msg);
+        }
          // release query buffer
-         mysql_free_result(result);
-        return 0;
-    }
-	
-    row = mysql_fetch_row(result);
-	
-    if( row[0] == NULL ) {
-        if(debug_level & 1)
-            fprintf(stderr,"err: NULL result for timestamp query\n");
-        // release query buffer
         mysql_free_result(result);
-        return 0;
+        return -1;
     }
-    // if no new data. exit with negative status
-		
-    if (!strncmp(last_timestamp, row[0], 11)) {
-        if (debug_level & 1)
-            fprintf(stderr,"info: No new weather data recorded - exiting: negative data\n");
+
+    row = mysql_fetch_row(result);
+
+     if( row[0] == NULL ) {
+         sprintf(death_msg,"err: NULL result for timestamp query\n");
+         if (debug_level & 1){
+             fprintf(stderr,"%s",death_msg);
+         }
         // release query buffer
         mysql_free_result(result);
         return -1;
     }
-    strcpy(last_timestamp, row[0]);	  // For next pass & following query
-        
-    if( debug_level & 1) fprintf(stdout,"Timestamp: %s\n",last_timestamp);
-	
-    // release query buffer
-    mysql_free_result(result);
+    // if no new data, exit with zero status
 
-    sprintf(query_buffer,"SELECT value,sensorid,fieldid FROM sdata WHERE timekey = %s", last_timestamp);
-
-    if (mysql_query(&mysql, query_buffer)) {
-        if (debug_level & 1) 
-            fprintf(stderr,"err: Latest Weather Data query failed - exiting: %s\n\t --Query: %s\n", 
-                mysql_error(&mysql), query_buffer);
-        return 0;
-    }
-
-    if (!(result = mysql_store_result(&mysql))) {
+    if (!strncmp(last_timestamp, row[0], 11)) {
         if (debug_level & 1)
-            fprintf(stderr,"err: Latest Weather Data query failed - exiting: %s\n", mysql_error(&mysql));
-        return 0;
-    }
-    if ((nrows=mysql_num_rows(result)) < 1 ) {
-        if (debug_level & 1)
-            fprintf(stderr,"err: Latest Weather Data query failed - exiting: number of results %d\n",nrows);
+            fprintf(stderr,"info: No new weather data recorded - exiting: no data\n");
         // release query buffer
         mysql_free_result(result);
         return 0;
+    }
+    strcpy(last_timestamp, row[0]);	  // For next pass & following query
+        
+    if( debug_level & 1) fprintf(stdout,"Timestamp: %s\n",last_timestamp);
+
+    // release query buffer
+    mysql_free_result(result);
+
+    sprintf(query_buffer,"SELECT value,sensorid,fieldid,from_unixtime(timekey,'%%m%%d%%H%%i%%S') FROM sdata WHERE timekey = %s", last_timestamp);
+
+    if (mysql_query(&mysql, query_buffer)) {
+        sprintf(death_msg,"err: Latest Weather Data query failed - exiting: %s\n\t --Query: %s\n", 
+                mysql_error(&mysql), query_buffer);
+        if (debug_level & 1){
+            fprintf(stderr,"%s",death_msg);
+        }
+        return -1;
+    }
+
+    if (!(result = mysql_store_result(&mysql))) {
+        sprintf(death_msg,"err: Latest Weather Data query failed - exiting: %s\n", mysql_error(&mysql));
+        if (debug_level & 1){
+            fprintf(stderr,"%s",death_msg);
+        }
+        return -1;
+    }
+    if ((nrows=mysql_num_rows(result)) < 1 ) {
+        sprintf(death_msg,"err: Latest Weather Data query failed - exiting: number of results %d\n",nrows);
+        if (debug_level & 1){
+            fprintf(stderr,"%s",death_msg);
+        }
+        // release query buffer
+        mysql_free_result(result);
+        return -1;
     } 
     else {
         if (debug_level & 1)
             fprintf(stderr,"info: Latest Weather Data query: number of types of readings %d\n",nrows);
     }
-	
+
     *valid_data_flgs = 0;
     item_count = 0;
     for (row_cnt = 0; row_cnt < nrows; row_cnt++) {
         row = mysql_fetch_row(result);
+        strcpy(last_datetime,row[3]);
 
         if(atoi(row[1]) == outdoor_instr) {	 // sensors are really groups of data
-
+            found_sensor = atoi(row[1]);
             if(debug_level & 1)
-                fprintf(stderr,"info: found an outdoor sensor: ");
+                fprintf(stderr,"info: found an outdoor sensor: (%d) ",found_sensor);
             
             switch (atoi(row[2]))  {  // type of reading
                 case WIND_DIRECTION :
@@ -566,20 +614,6 @@ int Get_Latest_WX( double *winddir,
                     if(debug_level & 1)
                         fprintf(stderr,"temperature %f\n ",*temp);
                     break;
-                case RAIN_PER_HOUR :
-                    *rain1hr = strtod(row[0],NULL);
-                    *valid_data_flgs |= VALID_RAIN1HR;
-                    item_count++;
-                    if(debug_level & 1)
-                        fprintf(stderr,"rainfall for 1 hr %f\n ",*rain1hr);
-                    break;
-                case RAIN_PER_DAY :
-                    *rain24h = strtod(row[0],NULL);
-                    *valid_data_flgs |= VALID_RAIN24H;
-                    item_count++;
-                    if(debug_level & 1)
-                        fprintf(stderr,"rainfall for 24 hrs %f\n ",*rain24h);
-                    break;
                 case HUMIDITY :
                     *humidity = strtod(row[0],NULL);
                     *valid_data_flgs |= VALID_HUMIDITY;
@@ -594,12 +628,32 @@ int Get_Latest_WX( double *winddir,
                     if(debug_level & 1)
                         fprintf(stderr,"air pressure %f\n ",*airpressure);
                     break;
+                case RAIN_PER_DAY :
+                    if(debug_level & 1)
+                        fprintf(stderr,"rain-per-day total (not used), now calculated...\n ");
+                    break;
+                case WIND_X :
+                   if(debug_level & 1)
+                       fprintf(stderr,"wind x... not used \n");
+                   break;
+                case WIND_Y :
+                   if(debug_level & 1)
+                       fprintf(stderr,"wind y... not used \n");
+                   break;
+                case DURATION :
+                   if(debug_level & 1)
+                      fprintf(stderr,"duration... not used \n");
+                   break;
+                case SAMPLES :
+                   if(debug_level & 1)
+                      fprintf(stderr,"samples... not used \n");
+                   break;
                 default :
                     if(debug_level & 1) fprintf(stderr,"unknown field %s\n",row[2]);
                     break;
             }
-        } 
-        else {
+        }
+        else {      // Must be indoor
             if (debug_level & 1) fprintf(stderr,"info: indoor sensor found\n");
             switch (atoi(row[2]))  {  // type of reading
                 case AIR_PRESSURE :
@@ -612,20 +666,174 @@ int Get_Latest_WX( double *winddir,
                  default :
                     if(debug_level & 1) fprintf(stderr,"unused field %s\n",row[2]);
                     break;
-            }         
+            }
         }
     }
 
-    *Metric_Data = 1;  // Always for meteo 
-    // release query buffer	& close connection
+    if(debug_level & 1) fprintf(stderr,"loop ends\n");
+    // release query buffer
     mysql_free_result(result);
 
-    if (debug_level & 1)
-        fprintf(stderr,"info: success - Weather Data number of reading types %d\n",
-             item_count);
+    /*        get rain figures	*/
+    /*
+    /*        hourly first		*/
+    last_hour_timestamp = atol(last_timestamp) - 3600;
+    sprintf(query_buffer,"SELECT round(sum(value),2) FROM sdata WHERE timekey > %ld and fieldid = %d", last_hour_timestamp,RAIN);
+
+    if (mysql_query(&mysql, query_buffer)) {
+        sprintf(death_msg,"err: rain 1 hour query failed - exiting: %s\n\t --Query: %s\n", mysql_error(&mysql), query_buffer);
+        if (debug_level & 1) fprintf(stderr,"%s",death_msg);
+        return -1;
+     }
+    if (!(result = mysql_store_result(&mysql))) {
+        sprintf(death_msg,"err: rain 1 hour store failed - exiting: %s\n", mysql_error(&mysql));
+        if (debug_level & 1) fprintf(stderr,"%s",death_msg);
+        return -1;
+    }
+    if ((mysql_num_rows(result)) > 0) {
+        row = mysql_fetch_row(result);
+        if (row[0] != NULL) {
+            *rain1hr = strtod(row[0],NULL);
+            if(debug_level & 1) fprintf(stderr,"rain last hour %f\n ",*rain1hr);
+            // *rain1hr = *rain1hr * 100;  // AFTER metric conversion if needed
+            *valid_data_flgs |= VALID_RAIN;
+            item_count++;
+        }
+        else {
+            *rain1hr = 0;
+            *valid_data_flgs |= VALID_RAIN;   //None, but valid
+            if(debug_level & 1) fprintf(stderr,"no rain recorded in last hour\n");
+        }
+    }     
+    // release query buffer
+    mysql_free_result(result);
+
+/*    Last 24 hours    */
+
+    last_24_timestamp = atol(last_timestamp) - 86400;
+    sprintf(query_buffer,"SELECT round(sum(value),2) FROM sdata WHERE timekey > %ld and fieldid = %d", last_24_timestamp,RAIN);
+
+    if (mysql_query(&mysql, query_buffer)) {
+        sprintf(death_msg,"err: rain 24 hour query failed - exiting: %s\n\t --Query: %s\n", mysql_error(&mysql), query_buffer);
+        if (debug_level & 1) fprintf(stderr,"%s",death_msg);
+        return -1;
+    }
+    if (!(result = mysql_store_result(&mysql))) {
+        sprintf(death_msg,"err: rain 24 hour store failed - exiting: %s\n", mysql_error(&mysql));
+        if (debug_level & 1) fprintf(stderr,"%s",death_msg);
+        return -1;
+    }
+    if ((mysql_num_rows(result)) > 0) {
+        row = mysql_fetch_row(result);
+        if (row[0] != NULL) {
+            *rain24hr = strtod(row[0],NULL);
+            if(debug_level & 1) fprintf(stderr,"rain last 24 hours %f\n ",*rain24hr);
+            //*rain24hr = *rain24hr * 100;	   // After metric conversion, if needed
+            item_count++;
+            *valid_data_flgs |= VALID_RAIN24H;
+        }
+        else {
+           *rain24hr = 0;
+           *valid_data_flgs |= VALID_RAIN24H;   // Zero is valid too
+           if(debug_level & 1) fprintf(stderr,"no rain recorded in last 24 hours\n");
+        }
+    }     
+    // release query buffer
+    mysql_free_result(result);
+#define CALC_MIDNIGHT
+#ifdef CALC_MIDNIGHT
+    // Timestamps are seconds since midnight Jan 1 1970, so an integer divide and multiply by 
+    // seconds in 24 hrs (86400) yields the latest midnight time stamp value.
+    last_day_timestamp = (atol(last_timestamp) / 86400)*86400;
+    if(debug_level & 1)
+        fprintf(stderr,"info: timestamp for prior midnight - %ld\n",last_day_timestamp);
+    sprintf(query_buffer,"SELECT offset FROM station WHERE id = (SELECT stationid from sensor WHERE id = %d)", found_sensor);
+    if (mysql_query(&mysql, query_buffer)) {
+        sprintf(death_msg,"err: station time offset query failed - exiting: %s\n\t --Query: %s\n", mysql_error(&mysql), query_buffer);
+        if (debug_level & 1) fprintf(stderr,"%s",death_msg);
+        return -1;
+    }
+    if (!(result = mysql_store_result(&mysql))) {
+        sprintf(death_msg,"err: station time offset store failed - exiting: %s\n", mysql_error(&mysql));
+        if (debug_level & 1) fprintf(stderr,"%s",death_msg);
+        return -1;
+    }
+    if ((mysql_num_rows(result)) > 0) {
+        row = mysql_fetch_row(result);
+        if (row[0] != NULL) {
+            local_offset = atol(row[0]);
+            if (debug_level & 1) fprintf(stderr,"info: station time offset: %ld\n", local_offset);
+        }
+    }
+    mysql_free_result(result);
+#else
+
+/*    since midnite    */
+
+/*    we can get the timestamp for midnite from the avg table		*/
+    last_day_timestamp = 0;
+    sprintf(query_buffer,"SELECT max(timekey) FROM avg WHERE fieldid = %d and intval = 86400", last_hour_timestamp,RAIN);
+    if (mysql_query(&mysql, query_buffer)) {
+        sprintf(death_msg,"err: midnite timekey query failed - exiting: %s\n\t --Query: %s\n", mysql_error(&mysql), query_buffer);
+        if (debug_level & 1) fprintf(stderr,"%s",death_msg);
+        return -1;
+    }
+    if (!(result = mysql_store_result(&mysql))) {
+        sprintf(death_msg,"err: midnite timekey store failed - exiting: %s\n", mysql_error(&mysql));
+        if (debug_level & 1) fprintf(stderr,"%s",death_msg);
+        return -1;
+    }
+    if ((mysql_num_rows(result)) > 0) {
+        row = mysql_fetch_row(result);
+        if (row[0] != NULL) {
+            last_day_timestamp = strtod(row[0],NULL);
+        }
+    }
+    mysql_free_result(result);
+#endif
+
+    if (last_day_timestamp > 0) {
+#ifndef CALC_MIDNIGHT
+        last_day_timestamp += 115200;	// add 8 hours for offset - this should really be queried
+#else
+        last_day_timestamp -= local_offset; // From the database
+#endif
+        sprintf(query_buffer,"SELECT round(sum(value),2) FROM sdata WHERE timekey > %ld and fieldid = %d", last_day_timestamp,RAIN);
+        if (mysql_query(&mysql, query_buffer)) {
+            sprintf(death_msg,"err: rain last day query failed - exiting: %s\n\t --Query: %s\n", mysql_error(&mysql), query_buffer);
+            if (debug_level & 1) fprintf(stderr,"%s",death_msg);
+            return -1;
+        }
+        if (!(result = mysql_store_result(&mysql))) {
+            sprintf(death_msg,"err: rain last day store failed - exiting: %s\n", mysql_error(&mysql));
+            if (debug_level & 1) fprintf(stderr,"%s",death_msg);
+            return -1;
+        }
+        if ((mysql_num_rows(result)) > 0) {
+            row = mysql_fetch_row(result);
+            if (row[0] != NULL) {
+                *rainday = strtod(row[0],NULL);
+                if(debug_level & 1) fprintf(stderr,"rain since midnite %f\n ",*rainday);
+                // *rainday = *rainday * 100;  // AFTER metric conversion, if needed.
+                item_count++;
+                *valid_data_flgs |= VALID_RAINDAY;
+            }
+            else {
+                *rainday = 0;
+                *valid_data_flgs |= VALID_RAINDAY;  // None is valid...
+                if(debug_level & 1) fprintf(stderr,"no rain recorded in last 24 hours\n");
+            }
+        }
+
+        // release query buffer (where used)
+        mysql_free_result(result);
+
+    }
+    if (debug_level & 1) 
+        fprintf(stderr,"info: success - Weather Data number of reading types %d\n",item_count);
 
     return item_count;
-}				
+}
 
 
 
@@ -657,7 +865,7 @@ void pipe_handler(int sig)		/*  */
             SIGTERM signal handler
 
 *******************************************************************/
-void term_handler(int sig)		/*  */
+void term_handler(int sig)
 {
     if (debug_level & 1)
         fprintf(stderr, "info: %s - ordered to DIE, complying", progname);
@@ -681,27 +889,35 @@ void term_handler(int sig)		/*  */
 *******************************************************************/
 int main(int argc, char **argv)
 {
-    const char *flags = "Hhvnc:u:p:d:s:r";
+    const char *flags = "Hhvnmrc:u:p:d:s:i:";
     char WX_APRS[120];
+    char logstr[80];
     int data_len = 0 ;
     double winddir;
     double windspeed;				
     double windgust;
     double temp;
     double rain1hr;
-    double rain24h;
+    double rain24hr;
+    double rainday;
     double humidity;
     double airpressure;
     unsigned int valid_data_flgs;
-    int Metric_Data = 1, dsts = 0;
-    int  pid, s, clen = sizeof(struct sockaddr_in), fd[CONNECTIONS];
-    int *max = 0,  c, dly_cnt = 1;
+    int Metric_Dat, dsts = 0;
+    int  pid, s, fd[CONNECTIONS];
+    socklen_t clen = sizeof(struct sockaddr_in);
+    int *max = 0,  c;
     int not_a_daemon = 0, repetitive = 0, tcp_wx_port = PORT;
     int  i, index = 0;
     struct sockaddr_in server, client;
     struct in_addr bind_address;
     fd_set rfds;
     struct timeval tv;
+    int poll_interval = POLL_INTERVAL;
+    int dly_cnt = 1;
+    FILE *pidfile;
+    const char *pidfilename = "/var/run/db2APRS.pid";
+    char cmd[120];
 
     struct option longopt[] = {
         {"help", 0, 0, 'h'},
@@ -713,6 +929,8 @@ int main(int argc, char **argv)
         {"cport", 1, 0, 'c'},
         {"sensor",1, 0, 's'},
         {"nodaemon", 0, 0, 'n'},
+        {"interval",1, 0, 'i'},
+        {"metric",0, 0, 'm'},
         {0, 0, 0, 0}
     };
 
@@ -732,7 +950,7 @@ int main(int argc, char **argv)
         progname++;
 
     while ((opt = getopt_long(argc, argv, flags, longopt, &index)) != EOF) { 
-        switch (opt) {		/* parse command-line or CGI options */
+        switch (opt) {        /* parse command-line or CGI options */
             case 'r':
                 repetitive = 1;
                 break;
@@ -740,25 +958,30 @@ int main(int argc, char **argv)
                 fprintf(stdout,"Verbose mode set:\n");
                 debug_level = 1;
                 break;
-            case 'u':	 // mysql username 
+            case 'u':      // mysql username 
                 strncpy(db.user,(char *)optarg,30);
                 break;
-            case 'p':	 // mysql password 
+            case 'p':      // mysql password 
                 strncpy(db.pswrd,(char *)optarg,15);
                 break;
-            case 'd':	 // mysql database name
+            case 'd':      // mysql database name
                 strncpy(db.name,(char *)optarg,30);
                 break;
-            case 'n':			/* do not fork and become a daemon */
+            case 'n':       /* do not fork and become a daemon */
                 not_a_daemon = 1;
                 break;
-            case 'c':			/* port to use */
+            case 'c':       /* port to use */
                 tcp_wx_port = strtol(optarg, NULL, 0);
                 break;
             case 's':                   /* sensor number for outdoor data */
                 outdoor_instr  = atoi(optarg);
                 break;
- 
+            case 'i':                   /* polling interval in seconds */
+                poll_interval  = atoi(optarg);
+                break;
+            case 'm':                   // Metric data from data base
+                Metric_Dat = 1;
+                break;
             case '?':
             case 'h':
             case 'H':
@@ -780,16 +1003,33 @@ int main(int argc, char **argv)
         fprintf(stdout, "an with an outdoor sensor group number of %d\n",outdoor_instr);
     }
 
-        // Data base connection
-	
-	
+    if (!not_a_daemon) {            /* setup has worked; now become a daemon? */
+
+        if ((pid = fork()) == -1) {
+            syslog(LOG_ERR, "can't fork() to become daemon: %m"); 
+            exit(20);
+        }
+        else if (pid) {
+            pidfile = fopen(pidfilename, "w");
+            fprintf(pidfile,"%d\n",pid);
+            fclose(pidfile);
+            exit (0);
+        }
+        syslog(LOG_ERR, "Started\n"); 
+        setsid();
+        for (i = 0; i < NOFILE; i++) if ( i != s) close(i);
+    }
+
+         // Data base connection
+
+
     if (!(mysql_real_connect(&mysql, "localhost", db.user, db.pswrd, db.name, 0, NULL, 0))) {
         if (debug_level & 1)
             fprintf(stderr,"err: Data Base connect for user:%s to database:%s failed - exiting: \n\t%s\n",
-                db.user, db.name, mysql_error(&mysql));
+                    db.user, db.name, mysql_error(&mysql));
         exit(9);
     }
-	                                                                        
+
     server.sin_family = AF_INET;
     bind_address.s_addr = htonl(INADDR_ANY);
     server.sin_addr = bind_address;
@@ -828,46 +1068,38 @@ int main(int argc, char **argv)
     tv.tv_sec = 0;
     tv.tv_usec = 0;
 
-    if (!not_a_daemon) {			/* setup has worked; now become a daemon? */
-
-        if ((pid = fork()) == -1) {
-            syslog(LOG_ERR, "can't fork() to become daemon: %m"); 
-        exit(20);
-        } 
-        else if (pid)
-            exit (0);
-
-        setsid();
-        for (i = 0; i < NOFILE; i++) if ( i != s) close(i);
-    }
 
     /* catch signals to close the database connection */
     signal( SIGTERM, term_handler );/* termination */
     signal( SIGPWR, term_handler ); /* power failure */
 
     if (debug_level & 1) fprintf(stdout,"Main Loop...\n");
-    dly_cnt = 1;
-    do {	
-        if(!(dly_cnt--)) {	 
-            dly_cnt = 25;		// Every 'dly_cnt' passes check for WX data update
-            if((dsts = Get_Latest_WX(&winddir,&windspeed,&windgust,
-                &temp,&rain1hr,&rain24h,&humidity,&airpressure,
-                &valid_data_flgs,&Metric_Data)) !=0 ) {
-                if ( dsts > 0 ) {
-                    data_len = APRS_str(WX_APRS, winddir,windspeed,windgust,
-                        temp, rain1hr, rain24h, humidity, airpressure,
-                        valid_data_flgs, Metric_Data);
-
-                    if (!data_len) {
-                        if (debug_level & 1)
-                            fprintf(stderr, "err: WX info formatting problem!");                    
-                        exit(13);
-                    }
-                }
-            } 
-            else {
+    dly_cnt = 2; // initial delay
+    do {
+        if(!(dly_cnt--)) {
+            dly_cnt = poll_interval;    // Every 'dly_cnt' passes check for WX data update
+            dsts = Get_Latest_WX(&winddir,&windspeed,&windgust,
+                &temp,&rain1hr,&rain24hr,&rainday,&humidity,&airpressure, &valid_data_flgs);
+            if ( dsts < 0 ) {
+                if (debug_level & 1) fprintf(stderr, "err: Get_Latest returned %d\n",dsts);
+                syslog(LOG_ERR,death_msg);
                 exit(dsts);
             }
+            // If no new data, make no new string either...
+            if(dsts)
+            {
+                data_len = APRS_str(WX_APRS, last_datetime, winddir,windspeed,windgust,
+                    temp, rain1hr, rain24hr, rainday, humidity, airpressure, 
+                    valid_data_flgs,Metric_Dat);
+
+                if (!data_len) {
+                    if (debug_level & 1)
+                        fprintf(stderr, "err: WX info formatting problem!");
+                    syslog(LOG_ERR,"WX Data format error\n");
+                    exit(13);
+                 }
+            } else if (debug_level & 1)
+                 fprintf(stderr,"Found no new data this pass...\n");
         }
         FD_ZERO(&rfds);
         FD_SET(s, &rfds);
@@ -877,7 +1109,7 @@ int main(int argc, char **argv)
             if ((*current = accept(s, (struct sockaddr *)&client, &clen)) != -1)
                 write(*current, WX_APRS, data_len);
         }
-        if (dly_cnt == 25) {
+        if (dly_cnt == poll_interval) {
             if (debug_level & 1) fprintf(stdout,"Updating clients:");
             for (current = fd; current <=max; current++)
             if (*current > 0) {   // active socket
@@ -886,13 +1118,13 @@ int main(int argc, char **argv)
                 write(*current, WX_APRS, data_len);
         }
         if (debug_level & 1) fprintf(stdout," done\n");
-    }
-    sleep(1);	 // 	   
+        }
+        sleep(1);
     } while (repetitive);
 
     mysql_close(&mysql);
 
     if (debug_level & 1) fprintf(stdout,"Exiting normally.\n");
+    syslog(LOG_ERR,"Terminated normally\n");
     exit(0);
 }
-
