@@ -1,5 +1,5 @@
 /*
- * $Id: database.h,v 1.27 2006/05/30 15:18:06 we7u Exp $
+ * $Id: database.h,v 1.37 2006/09/19 15:58:56 chicoreus Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
@@ -22,6 +22,9 @@
  * Look at the README for more information on the program.
  */
 
+/* Note: this file should be called db.h, but was renamed to database.h
+ * to avoid conflicts with the Berkeley DB package.  */
+
 /*
  * Database structures
  *
@@ -369,6 +372,19 @@ typedef struct _DataRow {
     short flag;                 // several flags, see below
     char pos_amb;               // Position ambiguity, 0 = none,
                                 // 1 = 0.1 minute...
+
+    unsigned int error_ellipse_radius; // Degrades precision for this
+                                // station, from 0 to 65535 cm or
+                                // 655.35 meters.  Assigned when we
+                                // decode each type of packet.
+                                // Default is 6.0 meters (600 cm)
+                                // unless we know the GPS position
+                                // is augmented, or is degraded by
+                                // less precision in the packet.
+
+    unsigned int lat_precision;	// In 100ths of a second latitude
+    unsigned int lon_precision;	// In 100ths of a second longitude
+
     int trail_color;            // trail color (when assigned)
     char record_type;
     char data_via;              // L local, T TNC, I internet, F file
@@ -481,7 +497,9 @@ extern CADRow *CAD_list_head;
 
 
 
-// station flag definitions
+// station flag definitions.  We have 16 bits available here as
+// "flag" in "DataRow" is defined as a short.
+//
 #define ST_OBJECT       0x01    // station is an object
 #define ST_ITEM         0x02    // station is an item
 #define ST_ACTIVE       0x04    // station is active (deleted objects are
@@ -493,6 +511,8 @@ extern CADRow *CAD_list_head;
 #define ST_MSGCAP       0x80    // message capable (not used yet)
 #define ST_STATUS       0x100   // got real status message
 #define ST_INVIEW       0x200   // station is in current screen view
+#define ST_MYSTATION    0x400   // station is owned by my call-SSID
+#define ST_MYOBJITEM    0x800   // object/item owned by me
 
 
 #ifdef DATA_DEBUG
@@ -509,6 +529,9 @@ extern void db_init(void);
 
 //
 extern int is_my_call(char *call, int exact);
+extern int is_my_station(DataRow *p_station);
+extern int is_my_object_item(DataRow *p_station);
+
 void mscan_file(char msg_type, void (*function)(Message *fill));
 extern void msg_record_ack(char *to_call_sign, char *my_call, char *seq,
                            int timeout, int cancel);
@@ -524,7 +547,7 @@ extern void sort_display_file(char *filename, int size);
 extern void clear_sort_file(char *filename);
 extern void display_packet_data(void);
 extern int  redraw_on_new_packet_data;
-extern int decode_ax25_header(unsigned char *incoming_data, int *length);
+extern int decode_ax25_header(unsigned char *data_string, int *length);
 extern int decode_ax25_line(char *line, char from, int port, int dbadd);
 
 // utilities
@@ -558,6 +581,7 @@ extern DataRow *t_oldest; // pointer to first element in time ordered station
 extern DataRow *t_newest; // pointer to last element in time ordered station
                           // list
 extern void init_station_data(void);
+extern void Station_data(Widget w, XtPointer clientData, XtPointer calldata);
 extern int station_data_auto_update;
 extern int  next_station_name(DataRow **p_curr);
 extern int  prev_station_name(DataRow **p_curr);
