@@ -1,8 +1,8 @@
 /* -*- c-basic-offset: 4; indent-tabs-mode: nil -*-
- * $Id: dbfawk.c,v 1.28 2005/08/17 19:08:44 we7u Exp $
+ * $Id: dbfawk.c,v 1.32 2006/07/22 14:47:51 tvrusso Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
- * Copyright (C) 2003-2005  The Xastir Group
+ * Copyright (C) 2003-2006  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -48,7 +48,10 @@
 //
 
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif  // HAVE_CONFIG_H
+
 #if defined(WITH_DBFAWK) && defined(HAVE_LIBSHP) && defined(HAVE_LIBPCRE)
 #include <stdio.h>
 #include <string.h>
@@ -141,7 +144,8 @@ dbfawk_field_info *dbfawk_field_list(DBFHandle dbf, char *dbffields) {
     d = fi->name;
     while (*p && *p != ':') *d++ = *p++;
     if (*p == ':')
-      *d = *p++ = '\0';
+      *p++ = '\0';
+    *d='\0';
     fi->num = DBFGetFieldIndex(dbf, fi->name);
     fi->type = DBFGetFieldInfo(dbf, fi->num, junk, &w, &prec);
     sp = p;
@@ -200,6 +204,7 @@ dbfawk_sig_info *dbfawk_load_sigs(const char *dir, /* directory path */
         // Check for hidden files or directories
         if (e->d_name[0] == '.') {
             // Hidden, skip it
+            free(path);
             continue;
         }
 
@@ -213,11 +218,13 @@ dbfawk_sig_info *dbfawk_load_sigs(const char *dir, /* directory path */
 
         if (stat(fullpath, &nfile) != 0) {
             // Couldn't stat file
+            free(path);
             continue;
         }
 
         if ((nfile.st_mode & S_IFMT) != S_IFREG) {
             // Not a regular file
+            free(path);
             continue;
         }
  
