@@ -1,11 +1,14 @@
 
 
-// $Id: hashtable.c,v 1.5 2005/08/18 15:22:42 we7u Exp $
+// $Id: hashtable.c,v 1.7 2006/04/24 19:21:41 we7u Exp $
 
 
 /* Copyright (C) 2004 Christopher Clark <firstname.lastname@cl.cam.ac.uk> */
-/* Portions Copyright (C) 2004-2005  The Xastir Group */
+/* Portions Copyright (C) 2004-2006  The Xastir Group */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif  // HAVE_CONFIG_H
 
 #include <stdlib.h>
 #include <stdio.h>
