@@ -1,5 +1,5 @@
 /*
- * $Id: igate.c,v 1.53 2006/05/31 20:39:14 we7u Exp $
+ * $Id: igate.c,v 1.56 2006/07/19 14:40:46 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
@@ -553,12 +553,12 @@ void output_igate_net(char *line, int port, int third_party) {
                     "IGATE RF->NET(%c):%s\n",
                     third_party ? 'T':'N',
                     line);
-                log_data(LOGFILE_IGATE,temp);
+                log_data( get_user_base_dir(LOGFILE_IGATE), temp );
 
                 xastir_snprintf(temp,
                     sizeof(temp),
                     "REJECT: Packet was gated before or shouldn't be gated!\n");
-                log_data(LOGFILE_IGATE,temp);
+                log_data( get_user_base_dir(LOGFILE_IGATE), temp );
 
                 fprintf(stderr,temp);
         }
@@ -582,12 +582,12 @@ void output_igate_net(char *line, int port, int third_party) {
                 "IGATE RF->NET(%c):%s\n",
                 third_party ? 'T':'N',
                 line);
-            log_data(LOGFILE_IGATE,temp);
+            log_data( get_user_base_dir(LOGFILE_IGATE), temp );
 
             xastir_snprintf(temp,
                 sizeof(temp),
                 "REJECT: Third party traffic!\n");
-            log_data(LOGFILE_IGATE,temp);
+            log_data( get_user_base_dir(LOGFILE_IGATE), temp );
 
             fprintf(stderr,temp);
         }
@@ -611,12 +611,12 @@ void output_igate_net(char *line, int port, int third_party) {
                 "IGATE RF->NET(%c):%s\n",
                 third_party ? 'T':'N',
                 line);
-            log_data(LOGFILE_IGATE,temp);
+            log_data( get_user_base_dir(LOGFILE_IGATE), temp );
 
             xastir_snprintf(temp,
                 sizeof(temp),
                 "REJECT: General Query!\n");
-            log_data(LOGFILE_IGATE,temp);
+            log_data( get_user_base_dir(LOGFILE_IGATE), temp );
 
             fprintf(stderr,temp);
         }
@@ -643,12 +643,12 @@ void output_igate_net(char *line, int port, int third_party) {
                 "IGATE RF->NET(%c):%s\n",
                 third_party ? 'T':'N',
                 line);
-            log_data(LOGFILE_IGATE,temp);
+            log_data( get_user_base_dir(LOGFILE_IGATE), temp );
 
             xastir_snprintf(temp,
                 sizeof(temp),
                 "REJECT: From my call!\n");
-            log_data(LOGFILE_IGATE,temp);
+            log_data( get_user_base_dir(LOGFILE_IGATE), temp );
 
             fprintf(stderr,temp);
         }
@@ -696,13 +696,13 @@ end_critical_section(&devices_lock, "igate.c:output_igate_net" );
                 "IGATE RF->NET(%c):%s\n",
                 third_party ? 'T':'N',
                 line);
-            log_data(LOGFILE_IGATE,temp);
+            log_data( get_user_base_dir(LOGFILE_IGATE), temp );
 
             xastir_snprintf(temp,
                 sizeof(temp),
                 "REJECT: No RF->NET from input port [%d]!\n",
                 port);
-            log_data(LOGFILE_IGATE,temp);
+            log_data( get_user_base_dir(LOGFILE_IGATE), temp );
 
             fprintf(stderr,temp);
         }
@@ -739,7 +739,7 @@ end_critical_section(&devices_lock, "igate.c:output_igate_net" );
                         "IGATE RF->NET(%c):%s\n",
                         third_party ? 'T':'N',
                         line);
-                    log_data(LOGFILE_IGATE,temp);
+                    log_data( get_user_base_dir(LOGFILE_IGATE), temp );
 
                     first = 0;
                 }
@@ -753,7 +753,7 @@ end_critical_section(&devices_lock, "igate.c:output_igate_net" );
 
                 // log output
                 if (log_igate)
-                    log_data(LOGFILE_IGATE,temp);
+                    log_data( get_user_base_dir(LOGFILE_IGATE), temp );
 
                 if (debug_level & 1024)
                     fprintf(stderr,"%s\n",temp);
@@ -785,6 +785,7 @@ void output_igate_rf(char *from, char *call, char *path, char *line,
     char temp[MAX_LINE_SIZE+20];
     int x;
     int first = 1;
+    int found_in_nws_file = 0;
 
 
     if ( (from == NULL) || (call == NULL) || (path == NULL) || (line == NULL) )
@@ -797,29 +798,6 @@ void output_igate_rf(char *from, char *call, char *path, char *line,
     if (operate_as_an_igate <= 1)
         return;
 
-    // Check for TCPXX in string.  If found, we have an
-    // unregistered net user.
-    // I removed the trailing asterisk -we7u
-    if (strstr(path,"TCPXX") != NULL) {
-        // "TCPXX" was found in the header.  We have an
-        // unregistered user.
-        if (log_igate && (debug_level & 1024) ) {
-            xastir_snprintf(temp,
-                sizeof(temp),
-                "IGATE NET->RF(%c):%s\n",
-                third_party ? 'T':'N',
-                line);
-            log_data(LOGFILE_IGATE,temp);
-
-            xastir_snprintf(temp,
-                sizeof(temp),
-                "REJECT: Unregistered net user!\n");
-            log_data(LOGFILE_IGATE,temp);
-            fprintf(stderr,temp);
-        }
-        return;
-    }
-
     // Don't gate anything with NOGATE in it, in either direction.
     // Same for OpenTrac packets.
     if ( (strstr(path,"NOGATE") != NULL)
@@ -832,12 +810,12 @@ void output_igate_rf(char *from, char *call, char *path, char *line,
                 "IGATE NET->RF(%c):%s\n",
                 third_party ? 'T':'N',
                 line);
-            log_data(LOGFILE_IGATE,temp);
+            log_data( get_user_base_dir(LOGFILE_IGATE), temp );
 
             xastir_snprintf(temp,
                 sizeof(temp),
                 "REJECT: NOGATE found in path or shouldn't be gated!\n");
-            log_data(LOGFILE_IGATE,temp);
+            log_data( get_user_base_dir(LOGFILE_IGATE), temp );
             fprintf(stderr,temp);
         }
         return;
@@ -858,12 +836,12 @@ void output_igate_rf(char *from, char *call, char *path, char *line,
                 "IGATE NET->RF(%c):%s\n",
                 third_party ? 'T':'N',
                 line);
-            log_data(LOGFILE_IGATE,temp);
+            log_data( get_user_base_dir(LOGFILE_IGATE), temp );
 
             xastir_snprintf(temp,
                 sizeof(temp),
                 "REJECT: General Query!\n");
-            log_data(LOGFILE_IGATE,temp);
+            log_data( get_user_base_dir(LOGFILE_IGATE), temp );
             fprintf(stderr,temp);
         }
         return;
@@ -878,12 +856,87 @@ void output_igate_rf(char *from, char *call, char *path, char *line,
     }
 
 
+    // Check whether gating of packets from this station/object/item
+    // has been specifically authorized via the nws-stations.txt
+    // mechanism.
+    //
+    if (object_name) {  // It's an object or item name
+
+        if ( check_NWS_stations( object_name ) ) {
+
+            found_in_nws_file++; // Object/Item is in nws-stations.txt
+        }
+    }
+    else {              // It's a station callsign
+
+        if ( check_NWS_stations( from ) ) {
+
+            found_in_nws_file++; // Source callsign is in nws-stations.txt
+        }
+    }
+// The above is really the same as the following code, but less
+// confusing:
+//    if (check_NWS_stations( (object_name) ? object_name : from ) ) {
+//        found_in_nws_file++;
+//    }      
+
+ 
+    // Check for TCPXX in string only if station wasn't found in the
+    // nws-stations.txt file.  If TCPXX found, we have an
+    // unregistered net user and the packet shouldn't normally head
+    // to RF.
+    //
+    // I removed the trailing asterisk -we7u
+    //
+    // Note that we CAN now gate stations to RF that have TCPXX in
+    // the string if they are authorized via the nws-stations.txt
+    // mechanism.
+    //
+    if (!found_in_nws_file) { // Skip this check if they're always authorized via the file
+
+        if (strstr(path,"TCPXX") != NULL) {
+
+            // "TCPXX" was found in the header.  We have an
+            // unregistered user.
+
+            if (log_igate && (debug_level & 1024) ) {
+                xastir_snprintf(temp,
+                    sizeof(temp),
+                    "IGATE NET->RF(%c):%s\n",
+                    third_party ? 'T':'N',
+                    line);
+                log_data( get_user_base_dir(LOGFILE_IGATE), temp );
+    
+                xastir_snprintf(temp,
+                    sizeof(temp),
+                    "REJECT: Unregistered net user!\n");
+                log_data( get_user_base_dir(LOGFILE_IGATE), temp );
+                fprintf(stderr,temp);
+            }
+            return;
+        }
+    }
+
+
+
+// If we made it to this point, the packet is from an authorized net
+// user (no TCPXX found in the path), or the callsign has been
+// authorized via the nws-stations.txt file (whether or not TCPXX
+// was found in the path).
+//
+// Found in file: Gate always
+//
+// Not found:     Gate if TCPXX not in path -AND- if destination
+//                station was heard in last hour on RF -AND- if
+//                source station was NOT heard in last hour on RF.
+
+
+
     // Check whether the source and destination calls have been
     // heard on local RF.
-    if (  (   (!object_name && !check_NWS_stations(from)) // Source call not in nws-stations.txt
-            || (object_name && !check_NWS_stations(object_name))) // Object/item not in nws-stations.txt
-        && (!heard_via_tnc_in_past_hour(call)==1        // Haven't heard destination call in previous hour
-            || heard_via_tnc_in_past_hour(from))) {  // Have heard source call in previous hour
+    if ( !found_in_nws_file // Skip this check if they're always authorized via the file
+         && ( !heard_via_tnc_in_past_hour(call)==1    // Haven't heard destination call in previous hour
+            || heard_via_tnc_in_past_hour(from)) ) {  // Have heard source call in previous hour
 
         if (log_igate && (debug_level & 1024) ) {
             xastir_snprintf(temp,
@@ -891,7 +944,7 @@ void output_igate_rf(char *from, char *call, char *path, char *line,
                 "IGATE NET->RF(%c):%s\n",
                 third_party ? 'T':'N',
                 line);
-            log_data(LOGFILE_IGATE,temp);
+            log_data( get_user_base_dir(LOGFILE_IGATE), temp );
 
         //  heard(call),  heard(from) : RF-to-RF talk
         // !heard(call),  heard(from) : Destination not heard on TNC
@@ -906,7 +959,7 @@ void output_igate_rf(char *from, char *call, char *path, char *line,
             xastir_snprintf(temp,
                 sizeof(temp),
                 "REJECT: RF->RF talk!\n");
-            log_data(LOGFILE_IGATE,temp);
+            log_data( get_user_base_dir(LOGFILE_IGATE), temp );
             fprintf(stderr,temp);
         }
         return;
@@ -959,7 +1012,7 @@ begin_critical_section(&devices_lock, "igate.c:output_igate_rf" );
                                 "IGATE NET->RF(%c):%s\n",
                                 third_party ? 'T':'N',
                                 line);
-                            log_data(LOGFILE_IGATE,temp);
+                            log_data( get_user_base_dir(LOGFILE_IGATE), temp );
                             first = 0;
                         }
 
@@ -970,7 +1023,7 @@ begin_critical_section(&devices_lock, "igate.c:output_igate_rf" );
 
                         // log output
                         if (log_igate)
-                            log_data(LOGFILE_IGATE,temp);
+                            log_data( get_user_base_dir(LOGFILE_IGATE), temp );
 
                         if (debug_level & 1024)
                             fprintf(stderr,temp);
@@ -996,13 +1049,13 @@ begin_critical_section(&devices_lock, "igate.c:output_igate_rf" );
                                 "IGATE NET->RF(%c):%s\n",
                                 third_party ? 'T':'N',
                                 line);
-                            log_data(LOGFILE_IGATE,temp);
+                            log_data( get_user_base_dir(LOGFILE_IGATE), temp );
 
                             xastir_snprintf(temp,
                                 sizeof(temp),
                                 "REJECT: NET->RF on port [%d]!\n",
                                 x);
-                            log_data(LOGFILE_IGATE,temp);
+                            log_data( get_user_base_dir(LOGFILE_IGATE), temp );
                             fprintf(stderr,temp);
                         }
                     }
@@ -1194,12 +1247,12 @@ void output_nws_igate_rf(char *from, char *path, char *line, int port, int third
                 "NWS IGATE NET->RF(%c):%s\n",
                 third_party ? 'T':'N',
                 line);
-            log_data(LOGFILE_IGATE,temp);
+            log_data( get_user_base_dir(LOGFILE_IGATE), temp );
 
             xastir_snprintf(temp,
                 sizeof(temp),
                 "REJECT: Unregistered net user!\n");
-            log_data(LOGFILE_IGATE,temp);
+            log_data( get_user_base_dir(LOGFILE_IGATE), temp );
             fprintf(stderr,temp);
         }
         return;
@@ -1216,12 +1269,12 @@ void output_nws_igate_rf(char *from, char *path, char *line, int port, int third
                 "NWS IGATE NET->RF(%c):%s\n",
                 third_party ? 'T':'N',
                 line);
-            log_data(LOGFILE_IGATE,temp);
+            log_data( get_user_base_dir(LOGFILE_IGATE), temp );
 
             xastir_snprintf(temp,
                 sizeof(temp),
                 "REJECT: NOGATE found in path!\n");
-            log_data(LOGFILE_IGATE,temp);
+            log_data( get_user_base_dir(LOGFILE_IGATE), temp );
             fprintf(stderr,temp);
         }
         return;
@@ -1235,12 +1288,12 @@ void output_nws_igate_rf(char *from, char *path, char *line, int port, int third
                 "NWS IGATE NET->RF(%c):%s\n",
                 third_party ? 'T':'N',
                 line);
-            log_data(LOGFILE_IGATE,temp);
+            log_data( get_user_base_dir(LOGFILE_IGATE), temp );
 
             xastir_snprintf(temp,
                 sizeof(temp),
                 "REJECT: No nws-stations.txt file!\n");
-            log_data(LOGFILE_IGATE,temp);
+            log_data( get_user_base_dir(LOGFILE_IGATE), temp );
             fprintf(stderr,temp);
         }
         return;
@@ -1262,12 +1315,12 @@ void output_nws_igate_rf(char *from, char *path, char *line, int port, int third
                 "NWS IGATE NET->RF(%c):%s\n",
                 third_party ? 'T':'N',
                 line);
-            log_data(LOGFILE_IGATE,temp);
+            log_data( get_user_base_dir(LOGFILE_IGATE), temp );
 
             xastir_snprintf(temp,
                 sizeof(temp),
                 "REJECT: No matching station in nws-stations.txt file!\n");
-            log_data(LOGFILE_IGATE,temp);
+            log_data( get_user_base_dir(LOGFILE_IGATE), temp );
             fprintf(stderr,temp);
         }
         return; // Match for station not found in file
@@ -1315,7 +1368,7 @@ begin_critical_section(&devices_lock, "igate.c:output_nws_igate_rf" );
                                 "NWS IGATE NET->RF(%c):%s\n",
                                 third_party ? 'T':'N',
                                 line);
-                            log_data(LOGFILE_IGATE,temp);
+                            log_data( get_user_base_dir(LOGFILE_IGATE), temp );
                             first = 0;
                         }
 
@@ -1326,7 +1379,7 @@ begin_critical_section(&devices_lock, "igate.c:output_nws_igate_rf" );
 
                         // log output
                         if (log_igate)
-                            log_data(LOGFILE_IGATE,temp);
+                            log_data( get_user_base_dir(LOGFILE_IGATE), temp );
 
                         if (debug_level & 1024)
                             fprintf(stderr,temp);
@@ -1350,13 +1403,13 @@ begin_critical_section(&devices_lock, "igate.c:output_nws_igate_rf" );
                                 "NWS IGATE NET->RF(%c):%s\n",
                                 third_party ? 'T':'N',
                                 line);
-                            log_data(LOGFILE_IGATE,temp);
+                            log_data( get_user_base_dir(LOGFILE_IGATE), temp );
 
                             xastir_snprintf(temp,
                                 sizeof(temp),
                                 "REJECT: NET->RF on port [%d]!\n",
                                 x);
-                            log_data(LOGFILE_IGATE,temp);
+                            log_data( get_user_base_dir(LOGFILE_IGATE), temp );
                             fprintf(stderr,temp);
                         }
                     }
