@@ -1,9 +1,9 @@
 /*
- * $Id: location_gui.c,v 1.16 2005/08/17 19:09:40 we7u Exp $
+ * $Id: location_gui.c,v 1.19 2006/08/07 19:50:12 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2005  The Xastir Group
+ * Copyright (C) 2000-2006  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,7 +22,9 @@
  * Look at the README for more information on the program.
  */
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif  // HAVE_CONFIG_H
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -333,8 +335,8 @@ void location_add(/*@unused@*/ Widget w, XtPointer clientData, /*@unused@*/ XtPo
         if (len>0 && len<100){
             fout = fopen(get_user_base_dir("config/locations.sys"),"a");
             if (fout!=NULL) {
-                convert_lat_l2s(mid_y_lat_offset, s_lat, sizeof(s_lat), CONVERT_HP_NOSP);
-                convert_lon_l2s(mid_x_long_offset, s_long, sizeof(s_long), CONVERT_HP_NOSP);
+                convert_lat_l2s(center_latitude, s_lat, sizeof(s_lat), CONVERT_HP_NOSP);
+                convert_lon_l2s(center_longitude, s_long, sizeof(s_long), CONVERT_HP_NOSP);
                 fprintf(fout,"%s|%s %s %ld\n",name,s_lat,s_long,scale_y);
                 (void)fclose(fout);
             }
