@@ -1,9 +1,9 @@
 /*
- * $Id: main.h,v 1.86 2005/10/24 19:29:23 we7u Exp $
+ * $Id: main.h,v 1.96 2006/09/19 14:43:46 chicoreus Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2005  The Xastir Group
+ * Copyright (C) 2000-2006  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -34,10 +34,24 @@
 #endif  // __linux__
 
 
-// Define this if your pthreads implementation uses SIGUSR1 signal.
-// This will disable our SIGUSR1 handler which allows us to create
-// snapshots on receipt of that signal.
-//#define OLD_PTHREADS
+// This gets defined if pthreads implementation uses SIGUSR1/SIGUSR2
+// signals.  This disables our SIGUSR1 handler which disallows
+// creating snapshots on receipt of that signal.  Old kernels (2.0
+// and early 2.1) had only 32 signals available so only USR1/USR2
+// were available for LinuxThreads use.  Newer kernels have more
+// signals available, making USR1/USR2 available to programs again.
+// _NSIG is defined in /usr/include/bits/signum.h
+//
+#ifdef __linux__
+# ifdef _NSIG
+#  if (_NSIG <= 32)
+#   define OLD_PTHREADS
+//#   warning ***** OLD_PTHREADS DETECTED *****
+#  else
+//#   warning ***** NEW_PTHREADS DETECTED *****
+#  endif // if (_NSIG...)
+# endif  // _NSIG
+#endif  // __linux__
 
 
 // To enable the "Transmit Raw WX data" button in
@@ -48,6 +62,10 @@
 //
 //#define TRANSMIT_RAW_WX
 
+// To use predefined object configuration files from within the 
+// user's base directory e.g. ~/.xastir/config/predefined_SAR.sys
+// rather than from the main base directory, enable this definition.
+//#define OBJECT_DEF_FILE_USER_BASE
 
 extern int enable_server_port;
 
@@ -82,13 +100,6 @@ extern int interrupt_drawing_now;
 #define MAX_PHG      8
 #define MAX_COMMENT  80
 
-#define MAX_UNPROTO  100
-
-#define MAX_TNC_CHARS 128
-#define MAX_NET_CHARS 128
-#define MAX_GPS_CHARS 128
-#define MAX_WX_CHARS 4
-
 
 
 //////////////////////////////////////////////////////////////////////
@@ -138,7 +149,9 @@ extern char SYMBOLS_DIR[400];
 extern char LOGFILE_IGATE[400];
 extern char LOGFILE_TNC[400];
 extern char LOGFILE_NET[400];
+extern char LOGFILE_MESSAGE[400];
 extern char LOGFILE_WX[400];
+extern char LOGFILE_WX_ALERT[400];
 extern char HELP_FILE[];
 extern char SOUND_DIR[400];
 extern time_t WX_ALERTS_REFRESH_TIME;
@@ -170,6 +183,10 @@ extern int view_zero_distance_bulletins;
 extern int warn_about_mouse_modifiers;
 extern int predefined_menu_from_file;
 
+extern int draw_labeled_grid_border;  // used to turn on or off border on map
+
+extern int my_trail_diff_color;  // trails for mycall with different ssids have the same or a different color
+
 extern int output_station_type;
 
 extern int emergency_beacon;
@@ -251,6 +268,8 @@ extern int transmit_compressed_objects_items;
 extern int log_igate;
 extern int log_tnc_data;
 extern int log_net_data;
+extern int log_message_data;
+extern int log_wx_alert_data;
 extern int log_wx;
 extern int snapshots_enabled;
 extern char user_dir[];
@@ -298,6 +317,8 @@ extern int dead_reckoning_timeout;
 extern char bando_min[30];
 extern char bando_max[30];
 extern int Display_packet_data_type;
+extern int show_only_station_capabilities;
+extern int Display_packet_data_mine_only;
 extern int menu_x;
 extern int menu_y;
 extern long my_last_altitude;
@@ -318,6 +339,8 @@ extern int posit_tx_disable;
 extern int object_tx_disable;
 extern int map_chooser_expand_dirs;
 extern int request_new_image;
+extern int disable_all_popups;
+extern char temp_tracking_station_call[30];
 
 extern int coordinate_system;
 #define USE_DDDDDD      0
@@ -393,7 +416,6 @@ extern void updateObjectPictureCallback(Widget w,XtPointer clientData,XtPointer
 
 extern void Draw_All_CAD_Objects(Widget w);
 
-
 // unit conversion
 extern char un_alt[2+1];
 extern char un_dst[2+1];
