@@ -1,9 +1,9 @@
 /* -*- c-basic-offset: 4; indent-tabs-mode: nil -*-
- * $Id: map_geo.c,v 1.62 2005/10/20 01:29:56 we7u Exp $
+ * $Id: map_geo.c,v 1.73 2006/10/24 18:02:24 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2005  The Xastir Group
+ * Copyright (C) 2000-2006  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -24,7 +24,10 @@
 
 //#define FUZZYRASTER
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif  // HAVE_CONFIG_H
+
 #include "snprintf.h"
 
 #include <stdio.h>
@@ -278,10 +281,10 @@ void draw_toporama_map (Widget w,
 
 
     // Compute the center of our view in decimal lat/long.
-    left = (double)((x_long_offset - 64800000l )/360000.0);   // Lat/long Coordinates
-    top = (double)(-((y_lat_offset - 32400000l )/360000.0));  // Lat/long Coordinates
-    right = (double)(((x_long_offset + ((screen_width) * scale_x) ) - 64800000l)/360000.0);//Lat/long Coordinates
-    bottom = (double)(-(((y_lat_offset + ((screen_height) * scale_y)) - 32400000l)/360000.0));//Lat/long Coordinates
+    left = (double)((NW_corner_longitude - 64800000l )/360000.0);   // Lat/long Coordinates
+    top = (double)(-((NW_corner_latitude - 32400000l )/360000.0));  // Lat/long Coordinates
+    right = (double)((SE_corner_longitude - 64800000l)/360000.0);//Lat/long Coordinates
+    bottom = (double)(-((SE_corner_latitude - 32400000l)/360000.0));//Lat/long Coordinates
 
     long_center = (left + right)/2.0l;
     lat_center  = (top + bottom)/2.0l;
@@ -528,7 +531,8 @@ void draw_geo_image_map (Widget w,
     // Terraserver variables
     double top_n=0, left_e=0, bottom_n=0, right_e=0, map_top_n=0, map_left_e=0;
     int z, url_n=0, url_e=0, t_zoom=16, t_scale=12800;
-    char zstr[8];
+    char zstr0[8];
+    char zstr1[8];
 #else   // HAVE_IMAGEMAGICK
     XImage *xi;                 // Temp XImage used for reading in current image
 #endif // HAVE_IMAGEMAGICK
@@ -717,19 +721,48 @@ void draw_geo_image_map (Widget w,
                     fprintf(stderr,"draw_geo_image_map:sscanf parsing error\n");
                 }
 
-                // Mask it with the color depth so that we don't
-                // check too many bits when looking for the
-                // transparent color.
-//fprintf(stderr,"Transparent: %lx\n",trans_color);
-//fprintf(stderr,"Visual depth: %d\n", visual_depth);
-                if (visual_depth <= 8) {
-                    trans_color = trans_color & 0x0000000ffl;
-                }
-                else if (visual_depth <= 16) {
-                     trans_color = trans_color & 0x00000ffffl;
-                }
-                else if (visual_depth <= 24) {
-                     trans_color = trans_color & 0x000ffffffl;
+                {
+                    unsigned short r,g,b;
+                    // We'll assume the trans_color has been specified as a 
+                    // 24-bit quantity
+                    r = (trans_color&0xff0000) >> 16;
+                    g = (trans_color&0x00ff00)>>8;
+                    b = trans_color&0x0000ff;
+                    // Now this is an incredible kludge, but seems to be right
+                    // Apparently, if QuantumDepth is 16 bits, r, g, and b
+                    // values are duplicated in the high and low byte, which
+                    // is just bizarre
+#ifdef HAVE_IMAGEMAGICK
+                    if (QuantumDepth == 16) {
+                        r=r|(r<<8);
+                        g=g|(g<<8);
+                        b=b|(b<<8);
+                    }
+#endif  // HAVE_IMAGEMAGICK
+                    //fprintf(stderr,"Original Transparent %lx\n",trans_color);
+                    //fprintf(stderr,"Transparent r,g,b=%x,%x,%x\n",r,g,b);
+                    if (visual_type == NOT_TRUE_NOR_DIRECT) {
+                        XColor junk;
+
+#ifdef HAVE_IMAGEMAGICK
+                        if (QuantumDepth == 16) {
+                            junk.red=r;
+                            junk.green=g;
+                            junk.blue=b;
+                        }
+                        else
+#endif  // HAVE_IMAGEMAGICK
+                        {
+                            junk.red= r<<8;
+                            junk.green = g<<8;
+                            junk.blue = b<<8;
+                        }
+                        XAllocColor(XtDisplay(w),cmap,&junk);
+                        trans_color = junk.pixel;
+                    } else {
+                        pack_pixel_bits(r,g,b,&trans_color);
+                    }
+                    //fprintf(stderr,"Packed Transparent %lx\n",trans_color);
                 }
 
                 do_check_trans = 1;
@@ -921,40 +954,53 @@ void draw_geo_image_map (Widget w,
             t_scale = 12800;
         }
 
-        top  = -((y_lat_offset - 32400000l) / 360000.0);
-        left =  (x_long_offset - 64800000l) / 360000.0;
+        top  = -((NW_corner_latitude - 32400000l) / 360000.0);
+        left =  (NW_corner_longitude - 64800000l) / 360000.0;
         ll_to_utm_ups(gDatum[D_NAD_83_CONUS].ellipsoid,
             top,
             left,
             &top_n,
             &left_e,
-            zstr,
-            sizeof(zstr) );
-        if (1 != sscanf(zstr, "%d", &z)) {
+            zstr0,
+            sizeof(zstr0) );
+        if (1 != sscanf(zstr0, "%d", &z)) {
             fprintf(stderr,"draw_geo_image_map:sscanf parsing error\n");
         }
 
-        bottom = -(((y_lat_offset + (screen_height * scale_y)) - 32400000l) / 360000.0);
-        right  =   ((x_long_offset + (screen_width * scale_x)) - 64800000l) / 360000.0;
+        bottom = -((SE_corner_latitude - 32400000l) / 360000.0);
+        right  =   (SE_corner_longitude - 64800000l) / 360000.0;
+
         ll_to_utm_ups(gDatum[D_NAD_83_CONUS].ellipsoid,
             bottom,
             right,
             &bottom_n,
             &right_e,
-            zstr,
-            sizeof(zstr) );
+            zstr1,
+            sizeof(zstr1) );
+
+
+//
+// NOTE:
+// POSSIBLE FUTURE ENHANCEMENT:
+// If zstr0 != zstr1, we have a viewscreen that crosses a UTM zone
+// boundary.  Terraserver/Toposerver will only feed us a map for one
+// side of it or the other.  It'd be VERY nice if some day we could
+// check for this condition and do two map loads instead of the one.
+// We'd need to stop drawing right at the boundary for each map
+// also, so that they'd tile together nicely.
+//
+
 
         map_top_n  = (int)((top_n  / t_scale) + 1) * t_scale;
         map_left_e = (int)((left_e / t_scale) + 0) * t_scale;
         utm_ups_to_ll(gDatum[D_NAD_83_CONUS].ellipsoid,
             map_top_n,
             map_left_e,
-            zstr,
+            zstr0,
             &top,
             &left);
 
 
-
 // Below here things can get messed up.  We can end up with very
 // large and/or negative values for geo_image_width and/or
 // geo_image_height.  Usually happens around UTM zone boundaries.
@@ -1033,7 +1079,6 @@ void draw_geo_image_map (Widget w,
         tp[1].x_long = 64800000l + (360000.0 * right);
         tp[1].y_lat  = 32400000l + (360000.0 * (-bottom));
 
-
         url_n = (int)(top_n  / t_scale); // The request URL does not use the
         url_e = (int)(left_e / t_scale); // N/E of the map corner
 
@@ -1066,10 +1111,10 @@ void draw_geo_image_map (Widget w,
     * Here are the corners of our viewport, using the Xastir
     * coordinate system.  Notice that Y is upside down:
     *
-    *   left edge of view = x_long_offset
-    *  right edge of view = x_long_offset + (screen_width  * scale_x)
-    *    top edge of view =  y_lat_offset
-    * bottom edge of view =  y_lat_offset + (screen_height * scale_y)
+    *   left edge of view = NW_corner_longitude
+    *  right edge of view = SE_corner_longitude
+    *    top edge of view =  NW_corner_latitude
+    * bottom edge of view =  SE_corner_latitude
     *
     * The corners of our map will soon be (after translating the
     * tiepoints to the corners if they're not already there):
@@ -1080,8 +1125,8 @@ void draw_geo_image_map (Widget w,
     * bottom edge of map = tp[1].y_lat
     *
     */
-    map_c_L = tp[0].x_long - x_long_offset;     // map left coordinate
-    map_c_T = tp[0].y_lat  - y_lat_offset;      // map top  coordinate
+    map_c_L = tp[0].x_long - NW_corner_longitude;     // map left coordinate
+    map_c_T = tp[0].y_lat  - NW_corner_latitude;      // map top  coordinate
 
     tp_c_dx = (long)(tp[1].x_long - tp[0].x_long);//  Width between tiepoints
     tp_c_dy = (long)(tp[1].y_lat  - tp[0].y_lat); // Height between tiepoints
@@ -1114,14 +1159,14 @@ void draw_geo_image_map (Widget w,
     // calculate top left map corner from tiepoints
     if (tp[0].img_x != 0) {
         tp[0].x_long -= (tp[0].img_x * map_c_dx);   // map left edge longitude
-        map_c_L = tp[0].x_long - x_long_offset;     // delta ??
+        map_c_L = tp[0].x_long - NW_corner_longitude;     // delta ??
         tp[0].img_x = 0;
         if (debug_level & 512)
             fprintf(stderr,"Translated tiepoint_0 x: %d\t%lu\n", tp[0].img_x, tp[0].x_long);
     }
     if (tp[0].img_y != 0) {
         tp[0].y_lat -= (tp[0].img_y * map_c_dy);    // map top edge latitude
-        map_c_T = tp[0].y_lat - y_lat_offset;
+        map_c_T = tp[0].y_lat - NW_corner_latitude;
         tp[0].img_y = 0;
         if (debug_level & 512)
             fprintf(stderr,"Translated tiepoint_0 y: %d\t%lu\n", tp[0].img_y, tp[0].y_lat);
@@ -1157,6 +1202,15 @@ void draw_geo_image_map (Widget w,
             if (f == NULL) {
 fprintf(stderr,"1 ");
                 fprintf(stderr,"File %s could not be read\n",image_info->filename);
+
+#ifdef USE_MAP_CACHE
+            // clear from cache if bad    
+            if (map_cache_del(fileimg)) {
+	        if (debug_level & 512) {
+                    fprintf(stderr,"Couldn't delete map from cache\n");
+	        }
+            }
+#endif
                 return;
             }
             (void)fclose (f);
@@ -1166,6 +1220,16 @@ fprintf(stderr,"1 ");
             if (image == (Image *) NULL) {
                 MagickWarning(exception.severity, exception.reason, exception.description);
                 //fprintf(stderr,"MagickWarning\n");
+
+#ifdef USE_MAP_CACHE
+            // clear from cache if bad    
+            if (map_cache_del(fileimg)) {
+	        if (debug_level & 512) {
+                    fprintf(stderr,"Couldn't delete map from cache\n");
+	        }
+            }
+#endif
+
                 return;
             }
             
@@ -1265,9 +1329,19 @@ fprintf(stderr,"1 ");
             fprintf(stderr,"Map not in current view, skipping: %s\n", file);
             fprintf(stderr,"\nImage: %s\n", file);
             fprintf(stderr,"Image size %d %d\n", geo_image_width, geo_image_height);
+            fprintf(stderr,"   Map:  lat0:%ld\t lon0:%ld\t lat1:%ld\t lon1:%ld\n",
+                tp[0].y_lat,
+                tp[0].x_long,
+                tp[1].y_lat,
+                tp[1].x_long);
+            fprintf(stderr,"Screen: NWlat:%ld\tNWlon:%ld\tSElat:%ld\tSElon:%ld\n",
+                NW_corner_latitude,
+                NW_corner_longitude,
+                SE_corner_latitude,
+                SE_corner_longitude);
             fprintf(stderr,"XX: %ld YY:%ld Sx %f %d Sy %f %d\n", map_c_L, map_c_T, map_c_dx,(int) (map_c_dx / scale_x), map_c_dy, (int) (map_c_dy / scale_y));
         }
-        return;            /* Skip this map */
+        return;            // Skip this map 
 #ifdef FUZZYRASTER 
    } else if (((float)(map_c_dx/scale_x) > rasterfuzz) ||
                ((float)(scale_x/map_c_dx) > rasterfuzz) ||
@@ -2157,13 +2231,13 @@ fprintf(stderr,"2 ");
 
     map_c_xc  = (tp[0].x_long + tp[1].x_long) / 2;  // hor center of map as reference
     map_x_ctr = (long)(width  / 2 +0.499);
-    scr_x_mc  = (map_c_xc - x_long_offset) / scale_x; // screen coordinates of map center
+    scr_x_mc  = (map_c_xc - NW_corner_longitude) / scale_x; // screen coordinates of map center
 
     // calculate map pixel range in y direction that falls into screen area
     c_y_max = 0ul;
     map_y_min = map_y_max = 0l;
     for (map_y_0 = 0, c_y = tp[0].y_lat; map_y_0 < (long)height; map_y_0++, c_y += map_c_dy) {
-        scr_y = (c_y - y_lat_offset) / scale_y;   // current screen position
+        scr_y = (c_y - NW_corner_latitude) / scale_y;   // current screen position
         if (scr_y > 0) {
             if (scr_y < screen_height) {
                 map_y_max = map_y_0;          // update last map pixel in y
@@ -2191,7 +2265,7 @@ fprintf(stderr,"2 ");
         // calculate map pixel range in x direction that falls into screen area
         map_x_min = map_x_max = 0l;
         for (map_x = 0, c_x = tp[0].x_long; map_x < (long)width; map_x++, c_x += map_c_dx) {
-            scr_x = (c_x - x_long_offset)/ scale_x;  // current screen position
+            scr_x = (c_x - NW_corner_longitude)/ scale_x;  // current screen position
             if (scr_x > 0) {
                 if (scr_x < screen_width)
                     map_x_max = map_x;          // update last map pixel in x
@@ -2208,12 +2282,12 @@ fprintf(stderr,"2 ");
 
     test = 1;           // DK7IN: debuging
     scr_yp = -1;
-    scr_c_xr = x_long_offset + screen_width * scale_x;
+    scr_c_xr = SE_corner_longitude;
     c_dx = map_c_dx;                            // map pixel width
     scale_xa = scale_x0;                        // the compiler likes it ;-)
 
 //    for (map_y_0 = 0, c_y = tp[0].y_lat; map_y_0 < (long)height; map_y_0++, c_y += map_c_dy) {
-//        scr_y = (c_y - y_lat_offset) / scale_y;   // current screen position
+//        scr_y = (c_y - NW_corner_latitude) / scale_y;   // current screen position
 
     map_done = 0;
     map_act  = 0;
@@ -2256,14 +2330,39 @@ fprintf(stderr,"2 ");
                 (map_y_0 <= map_y_max) || (map_proj == 1 && !map_done && scr_y < screen_height);
                 map_y_0++, c_y += map_c_dy) {
 
-        scr_y = (c_y - y_lat_offset) / scale_y;
+        HandlePendingEvents(app_context);
+        if (interrupt_drawing_now) {
+#ifdef HAVE_IMAGEMAGICK
+            if (image)
+                DestroyImage(image);
+            if (image_info)
+                DestroyImageInfo(image_info);
+#else   // HAVE_IMAGEMAGICK
+            if (xi)
+                XDestroyImage (xi);
+#endif // HAVE_IMAGEMAGICK
+            // Update to screen
+            (void)XCopyArea(XtDisplay(da),
+                pixmap,
+                XtWindow(da),
+                gc,
+                0,
+                0,
+                (unsigned int)screen_width,
+                (unsigned int)screen_height,
+                0,
+                0);
+            return;
+        }
+
+        scr_y = (c_y - NW_corner_latitude) / scale_y;
         if (scr_y != scr_yp) {                  // don't do a row twice
             scr_yp = scr_y;                     // remember as previous y
             if (map_proj == 1) {                // Transverse Mercator correction in x
                 scale_xa = get_x_scale(0,(long)c_y,scale_y); // recalc scale_x for current y
                 c_dx = map_c_dx * scale_xa / scale_x0;       // adjusted map pixel width
 
-                map_x_min = map_x_ctr - (map_c_xc - x_long_offset) / c_dx;
+                map_x_min = map_x_ctr - (map_c_xc - NW_corner_longitude) / c_dx;
                 if (map_x_min < 0)
                     map_x_min = 0;
                 c_x_min = map_c_xc - (map_x_ctr - map_x_min) * c_dx;
@@ -2281,7 +2380,7 @@ fprintf(stderr,"2 ");
             map_act = 0;
             scale_x_nm = calc_dscale_x(0,(long)c_y) / 1852.0;  // nm per Xastir coordinate
             for (map_x = map_x_min, c_x = (double)c_x_min; map_x <= map_x_max; map_x++, c_x += c_dx) {
-                scr_x = (c_x - x_long_offset) / scale_x;
+                scr_x = (c_x - NW_corner_longitude) / scale_x;
                 if (scr_x != scr_xp) {      // don't do a pixel twice
                     scr_xp = scr_x;         // remember as previous x
                     if (map_proj == 1) {    // Transverse Mercator correction in y
@@ -2383,5 +2482,3 @@ fprintf(stderr,"2 ");
 #endif  // TIMING_DEBUG
 #endif  // NO_GRAPHICS
 }
-
-
