@@ -1,9 +1,9 @@
 /* -*- c-basic-offset: 4; indent-tabs-mode: nil -*-
- * $Id: map_tiger.c,v 1.46 2005/10/20 01:29:56 we7u Exp $
+ * $Id: map_tiger.c,v 1.51 2006/08/07 19:53:10 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2005  The Xastir Group
+ * Copyright (C) 2000-2006  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,7 +23,10 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif  // HAVE_CONFIG_H
+
 #include "snprintf.h"
 
 #include <stdio.h>
@@ -362,21 +365,21 @@ void draw_tiger_map (Widget w,
     //
     tp[0].img_x = 0;                // Pixel Coordinates
     tp[0].img_y = 0;                // Pixel Coordinates
-    tp[0].x_long = x_long_offset;   // Xastir Coordinates
-    tp[0].y_lat  = y_lat_offset;    // Xastir Coordinates
+    tp[0].x_long = NW_corner_longitude;   // Xastir Coordinates
+    tp[0].y_lat  = NW_corner_latitude;    // Xastir Coordinates
 
     // Tiepoint for lower right screen corner
     //
     tp[1].img_x =  screen_width - 1; // Pixel Coordinates
     tp[1].img_y = screen_height - 1; // Pixel Coordinates 
 
-    tp[1].x_long = x_long_offset + (( screen_width) * scale_x); // Xastir Coordinates
-    tp[1].y_lat  =  y_lat_offset + ((screen_height) * scale_y); // Xastir Coordinates
+    tp[1].x_long = SE_corner_longitude; // Xastir Coordinates
+    tp[1].y_lat  =  SE_corner_latitude; // Xastir Coordinates
 
-    left = (double)((x_long_offset - 64800000l )/360000.0);   // Lat/long Coordinates
-    top = (double)(-((y_lat_offset - 32400000l )/360000.0));  // Lat/long Coordinates
-    right = (double)(((x_long_offset + ((screen_width) * scale_x) ) - 64800000l)/360000.0);//Lat/long Coordinates
-    bottom = (double)(-(((y_lat_offset + ((screen_height) * scale_y) ) - 32400000l)/360000.0));//Lat/long Coordinates
+    left = (double)((NW_corner_longitude - 64800000l )/360000.0);   // Lat/long Coordinates
+    top = (double)(-((NW_corner_latitude - 32400000l )/360000.0));  // Lat/long Coordinates
+    right = (double)((SE_corner_longitude - 64800000l)/360000.0);//Lat/long Coordinates
+    bottom = (double)(-((SE_corner_latitude - 32400000l)/360000.0));//Lat/long Coordinates
 
     map_width = right - left;   // Lat/long Coordinates
     map_height = top - bottom;  // Lat/long Coordinates
@@ -547,6 +550,17 @@ void draw_tiger_map (Widget w,
     if (f == NULL) {
         if (debug_level & 512)
             fprintf(stderr,"File could not be read\n");
+
+#ifdef USE_MAP_CACHE
+
+        // clear from cache if bad    
+        if (map_cache_del(fileimg)) {
+            if (debug_level & 512) {
+                fprintf(stderr,"Couldn't delete unreadable map from cache\n");
+            }
+        }
+#endif
+         
         return;
     }
     (void)fclose (f);
@@ -557,6 +571,16 @@ void draw_tiger_map (Widget w,
     if (image == (Image *) NULL) {
         MagickWarning(exception.severity, exception.reason, exception.description);
         //fprintf(stderr,"MagickWarning\n");
+
+#ifdef USE_MAP_CACHE
+        // clear from cache if bad    
+        if (map_cache_del(fileimg)) {
+            if (debug_level & 512) {
+                fprintf(stderr,"Couldn't delete map from cache\n");
+            }
+        }
+#endif
+
         return;
     }
 
@@ -688,10 +712,10 @@ void draw_tiger_map (Widget w,
     * Here are the corners of our viewport, using the Xastir
     * coordinate system.  Notice that Y is upside down:
     *
-    *   left edge of view = x_long_offset
-    *  right edge of view = x_long_offset + (screen_width  * scale_x)
-    *    top edge of view =  y_lat_offset
-    * bottom edge of view =  y_lat_offset + (screen_height * scale_y)
+    *   left edge of view = NW_corner_longitude
+    *  right edge of view = SE_corner_longitude
+    *    top edge of view =  NW_corner_latitude
+    * bottom edge of view =  SE_corner_latitude
     *
     * The corners of our map will soon be (after translating the
     * tiepoints to the corners if they're not already there):
@@ -702,8 +726,8 @@ void draw_tiger_map (Widget w,
     * bottom edge of map = tp[1].y_lat
     *
     */
-    map_c_L = tp[0].x_long - x_long_offset;     // map left coordinate
-    map_c_T = tp[0].y_lat  - y_lat_offset;      // map top  coordinate
+    map_c_L = tp[0].x_long - NW_corner_longitude;     // map left coordinate
+    map_c_T = tp[0].y_lat  - NW_corner_latitude;      // map top  coordinate
 
     tp_c_dx = (long)(tp[1].x_long - tp[0].x_long);//  Width between tiepoints
     tp_c_dy = (long)(tp[1].y_lat  - tp[0].y_lat); // Height between tiepoints
@@ -726,14 +750,14 @@ void draw_tiger_map (Widget w,
     // calculate top left map corner from tiepoints
     if (tp[0].img_x != 0) {
         tp[0].x_long -= (tp[0].img_x * map_c_dx);   // map left edge longitude
-        map_c_L = tp[0].x_long - x_long_offset;     // delta ??
+        map_c_L = tp[0].x_long - NW_corner_longitude;     // delta ??
         tp[0].img_x = 0;
         if (debug_level & 512)
             fprintf(stderr,"Translated tiepoint_0 x: %d\t%lu\n", tp[0].img_x, tp[0].x_long);
     }
     if (tp[0].img_y != 0) {
         tp[0].y_lat -= (tp[0].img_y * map_c_dy);    // map top edge latitude
-        map_c_T = tp[0].y_lat - y_lat_offset;
+        map_c_T = tp[0].y_lat - NW_corner_latitude;
         tp[0].img_y = 0;
         if (debug_level & 512)
             fprintf(stderr,"Translated tiepoint_0 y: %d\t%lu\n", tp[0].img_y, tp[0].y_lat);
@@ -784,13 +808,13 @@ void draw_tiger_map (Widget w,
 
     map_c_xc  = (tp[0].x_long + tp[1].x_long) / 2;  // hor center of map as reference
     map_x_ctr = (long)(width  / 2 +0.499);
-    scr_x_mc  = (map_c_xc - x_long_offset) / scale_x; // screen coordinates of map center
+    scr_x_mc  = (map_c_xc - NW_corner_longitude) / scale_x; // screen coordinates of map center
 
     // calculate map pixel range in y direction that falls into screen area
     c_y_max = 0ul;
     map_y_min = map_y_max = 0l;
     for (map_y_0 = 0, c_y = tp[0].y_lat; map_y_0 < (long)height; map_y_0++, c_y += map_c_dy) {
-        scr_y = (c_y - y_lat_offset) / scale_y;   // current screen position
+        scr_y = (c_y - NW_corner_latitude) / scale_y;   // current screen position
         if (scr_y > 0) {
             if (scr_y < screen_height) {
                 map_y_max = map_y_0;          // update last map pixel in y
@@ -805,7 +829,7 @@ void draw_tiger_map (Widget w,
 
         map_x_min = map_x_max = 0l;
         for (map_x = 0, c_x = tp[0].x_long; map_x < (long)width; map_x++, c_x += map_c_dx) {
-            scr_x = (c_x - x_long_offset)/ scale_x;  // current screen position
+            scr_x = (c_x - NW_corner_longitude)/ scale_x;  // current screen position
             if (scr_x > 0) {
                 if (scr_x < screen_width)
                     map_x_max = map_x;          // update last map pixel in x
@@ -818,7 +842,7 @@ void draw_tiger_map (Widget w,
         c_x_min = (unsigned long)(tp[0].x_long + map_x_min * map_c_dx);   // left map inside screen coordinate
 
     scr_yp = -1;
-    scr_c_xr = x_long_offset + screen_width * scale_x;
+    scr_c_xr = SE_corner_longitude;
     c_dx = map_c_dx;                            // map pixel width
     scale_xa = scale_x0;                        // the compiler likes it ;-)
 
@@ -831,7 +855,27 @@ void draw_tiger_map (Widget w,
     // loop over map pixel rows
     for (map_y_0 = map_y_min, c_y = (double)c_y_min; (map_y_0 <= map_y_max); map_y_0++, c_y += map_c_dy) {
 
-        scr_y = (c_y - y_lat_offset) / scale_y;
+        HandlePendingEvents(app_context);
+        if (interrupt_drawing_now) {
+            if (image)
+               DestroyImage(image);
+            if (image_info)
+               DestroyImageInfo(image_info);
+            // Update to screen
+            (void)XCopyArea(XtDisplay(da),
+                pixmap,
+                XtWindow(da),
+                gc,
+                0,
+                0,
+                (unsigned int)screen_width,
+                (unsigned int)screen_height,
+                0,
+                0);
+            return;
+        }
+
+        scr_y = (c_y - NW_corner_latitude) / scale_y;
         if (scr_y != scr_yp) {                  // don't do a row twice
             scr_yp = scr_y;                     // remember as previous y
             scr_xp = -1;
@@ -839,7 +883,7 @@ void draw_tiger_map (Widget w,
             map_act = 0;
             scale_x_nm = calc_dscale_x(0,(long)c_y) / 1852.0;  // nm per Xastir coordinate
             for (map_x = map_x_min, c_x = (double)c_x_min; map_x <= map_x_max; map_x++, c_x += c_dx) {
-                scr_x = (c_x - x_long_offset) / scale_x;
+                scr_x = (c_x - NW_corner_longitude) / scale_x;
                 if (scr_x != scr_xp) {      // don't do a pixel twice
                     scr_xp = scr_x;         // remember as previous x
                     map_y = map_y_0;
