@@ -1,9 +1,9 @@
 /* -*- c-basic-offset: 4; indent-tabs-mode: nil -*-
- * $Id: maps.h,v 1.56 2005/09/26 02:35:38 we7u Exp $
+ * $Id: maps.h,v 1.64 2006/08/31 21:36:06 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2005  The Xastir Group
+ * Copyright (C) 2000-2006  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -100,19 +100,19 @@ typedef struct {
     unsigned long y_lat;
 } tiepoint;
 
-extern void recompute_lat_long(void);
-
 void draw_point(Widget w,
                  unsigned long x1,
                  unsigned long y1,
                  GC gc,
-                 Pixmap which_pixmap);
+                 Pixmap which_pixmap,
+                 int skip_duplicates);
 
 void draw_point_ll(Widget w,
                  float y1,
                  float x1,
                  GC gc,
-                 Pixmap which_pixmap);
+                 Pixmap which_pixmap,
+                 int skip_duplicates);
 
 void draw_vector(Widget w,
                  unsigned long x1,
@@ -120,7 +120,8 @@ void draw_vector(Widget w,
                  unsigned long x2,
                  unsigned long y2,
                  GC gc,
-                 Pixmap which_pixmap);
+                 Pixmap which_pixmap,
+                 int skip_duplicates);
 
 void draw_vector_ll(Widget w,
                  float y1,
@@ -128,16 +129,18 @@ void draw_vector_ll(Widget w,
                  float y2,
                  float x2,
                  GC gc,
-                 Pixmap which_pixmap);
+                 Pixmap which_pixmap,
+                 int skip_duplicates);
 
 char *get_map_ext (char *filename);
 char *get_map_dir (char *fullpath);
 void load_auto_maps(Widget w, char *dir);
 void load_maps(Widget w);
-void fill_in_new_alert_entries(Widget w, char *dir);
+void fill_in_new_alert_entries(void);
 void load_alert_maps(Widget w, char *dir);
 void  index_update_xastir(char *filename, unsigned long bottom, unsigned long top, unsigned long left, unsigned long right, int default_map_layer);
 void  index_update_ll(char *filename, double bottom, double top, double left, double right, int default_map_layer);
+extern void get_horizontal_datum(char *datum, int sizeof_datum);
 void draw_grid (Widget w);
 void Snapshot(void);
 extern int index_retrieve(char *filename, unsigned long *bottom,
@@ -158,14 +161,14 @@ extern int map_visible (unsigned long bottom_map_boundary,
 extern int map_visible_lat_lon (double f_bottom_map_boundary,
                                 double f_top_map_boundary,
                                 double f_left_map_boundary,
-                                double f_right_map_boundary,
-                                char *error_message);
+                                double f_right_map_boundary);
 extern int map_inside_viewport_lat_lon(double map_min_y,
                                        double map_max_y,
                                        double map_min_x,
                                        double map_max_x);
 extern void draw_label_text (Widget w, int x, int y, int label_length, int color, char *label_text);
 extern void draw_rotated_label_text (Widget w, int rotation, int x, int y, int label_length, int color, char *label_text, int fontsize);
+extern int get_rotated_label_text_length_pixels(Widget w, char *label_text, int fontsize);
 extern void draw_centered_label_text (Widget w, int rotation, int x, int y, int label_length, int color, char *label_text, int fontsize);
 extern void  Monochrome( /*@unused@*/ Widget widget, XtPointer clientData, XtPointer callData);
 extern void Snapshot(void);
@@ -187,6 +190,7 @@ enum map_onscreen_enum {MAP_NOT_VIS=0,MAP_IS_VIS,MAP_NOT_INDEXED};
 extern enum map_onscreen_enum map_onscreen(long left, long right, long top, long bottom, int checkpercentage);
 extern enum map_onscreen_enum map_onscreen_index(char *filename);
 extern time_t last_snapshot;
+extern int snapshot_interval;
 
 extern int grid_size;
 
