@@ -1,9 +1,9 @@
 /*
- * $Id: messages.c,v 1.60 2005/10/13 00:09:52 we7u Exp $
+ * $Id: messages.c,v 1.69 2006/09/09 00:35:50 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2005  The Xastir Group
+ * Copyright (C) 2000-2006  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,7 +22,10 @@
  * Look at the README for more information on the program.
  */
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif  // HAVE_CONFIG_H
+
 #include "snprintf.h"
 
 #include <Xm/XmAll.h>
@@ -60,6 +63,7 @@
 #include "messages.h"
 #include "util.h"
 #include "interface.h"
+#include "xa_config.h"
 
 // Must be last include file
 #include "leak_detection.h"
@@ -97,7 +101,13 @@ begin_critical_section(&send_message_dialog_lock, "messages.c:clear_message_wind
         mw[i].send_message_dialog = (Widget)NULL;
         mw[i].to_call_sign[0] = '\0';
         mw[i].send_message_call_data = (Widget)NULL;
-        mw[i].send_message_message_data = (Widget)NULL;
+        mw[i].D700_mode = (Widget)NULL;
+        mw[i].D7_mode = (Widget)NULL;
+        mw[i].HamHUD_mode = (Widget)NULL;
+        mw[i].message_data_line1 = (Widget)NULL;
+        mw[i].message_data_line2 = (Widget)NULL;
+        mw[i].message_data_line3 = (Widget)NULL;
+        mw[i].message_data_line4 = (Widget)NULL;
         mw[i].send_message_text = (Widget)NULL;
     }
 
@@ -215,12 +225,12 @@ static int group_active(char *from) {
     (void)remove_trailing_spaces(from);
 
     // If we cycle to/from special group or file changes, rebuild group list.
-    if ((!stat(group_data_file, &group_stat)
+    if ((!stat( get_user_base_dir(group_data_file), &group_stat )
             && (current_group_stat.st_size != group_stat.st_size
                 || current_group_stat.st_mtime != group_stat.st_mtime
                 || current_group_stat.st_ctime != group_stat.st_ctime))
                 || (altgroup && strcasecmp(altgroup, VERSIONFRM))) {
-        group_build_list(group_data_file);
+        group_build_list( get_user_base_dir(group_data_file) );
         current_group_stat = group_stat;
         xastir_snprintf(altgroup,sizeof(altgroup),"%s",VERSIONFRM);
     }
@@ -355,7 +365,9 @@ end_critical_section(&send_message_dialog_lock, "messages.c:check_popup_window2"
                 from_call_sign,
                 sizeof(temp1) - strlen(temp1));
 
-            Send_message(appshell, temp1, NULL);
+            if (!disable_all_popups) {
+                Send_message(appshell, temp1, NULL);
+            }
 
             update_messages(1);
 
@@ -606,13 +618,15 @@ void bump_message_counter(void) {
 //
 void output_message(char *from, char *to, char *message, char *path) {
     int ok,i,j;
-    char message_out[MAX_MESSAGE_OUTPUT_LENGTH+1];
+    char message_out[MAX_MESSAGE_OUTPUT_LENGTH+1+5+1]; // +'{' +msg_id +terminator
     int last_space, message_ptr, space_loc;
     int wait_on_first_ack;
     int error;
     long record;
 
 
+//fprintf(stderr,"output_message:%s\n", message);
+
     message_ptr=0;
     last_space=0;
     ok=0;
@@ -633,22 +647,28 @@ void output_message(char *from, char *to, char *message, char *path) {
         // processed into APRS messages.  Break at a space character
         // if possible.
         //
-        for (j=0;j<MAX_MESSAGE_OUTPUT_LENGTH;j++) {
+        for (j=0; j<MAX_MESSAGE_OUTPUT_LENGTH; j++) {
+
             if(message[j+message_ptr] != '\0') {
+
                 if(message[j+message_ptr]==' ') {
                     last_space=j+message_ptr+1;
                     space_loc=j;
                 }
-                if ((j+1)!=MAX_MESSAGE_OUTPUT_LENGTH) {
+
+                if (j!=MAX_MESSAGE_OUTPUT_LENGTH) {
                     message_out[j]=message[j+message_ptr];
                     message_out[j+1] = '\0';
-                } else {
+                }
+                else {
+
                     if(space_loc!=0)
                         message_out[space_loc] = '\0';
                     else
                         last_space=j+message_ptr;
                 }
-            } else {
+            }
+            else {
                 j=MAX_MESSAGE_OUTPUT_LENGTH+1;
                 last_space=strlen(message)+1;
             }
@@ -659,7 +679,12 @@ void output_message(char *from, char *to, char *message, char *path) {
         if (debug_level & 2)
             fprintf(stderr,"MESSAGE <%s> %d %d\n",message_out,message_ptr,last_space);
 
-        message_ptr=last_space;
+        if (j >= MAX_MESSAGE_OUTPUT_LENGTH) {
+            message_ptr = MAX_MESSAGE_OUTPUT_LENGTH;
+        }
+        else {
+            message_ptr=last_space;
+        }
 
         /* check for others in the queue */
         wait_on_first_ack=0;
@@ -749,7 +774,7 @@ void output_message(char *from, char *to, char *message, char *path) {
 // this lock.
 end_critical_section(&send_message_dialog_lock, "db.c:update_messages" );
 
-                msg_data_add(to,
+                (void)msg_data_add(to,
                     from,
                     message_out,
                     message_pool[i].seq,
@@ -930,7 +955,7 @@ void transmit_message_data(char *to, char *message, char *path) {
 // Create a struct to hold the delayed ack's.
 typedef struct _delayed_ack_record {
     char to_call_sign[MAX_CALLSIGN+1];
-    char message_line[MAX_MESSAGE_OUTPUT_LENGTH+1];
+    char message_line[MAX_MESSAGE_OUTPUT_LENGTH+1+5+1];
     char path[200];
     time_t active_time;
     struct _delayed_ack_record *next;
@@ -1022,16 +1047,16 @@ void transmit_message_data_delayed(char *to, char *message,
 time_t delayed_transmit_last_check = (time_t)0;
 
 
-void check_delayed_transmit_queue(void) {
+void check_delayed_transmit_queue(int curr_sec) {
     delayed_ack_record_p ptr = delayed_ack_list_head;
     int active_records = 0;
 
 
     // Skip this function if we did it during this second already.
-    if (delayed_transmit_last_check == sec_now()) {
+    if (delayed_transmit_last_check == curr_sec) {
         return;
     }
-    delayed_transmit_last_check = sec_now();
+    delayed_transmit_last_check = curr_sec;
 
 //fprintf(stderr, "Checking delayed TX queue for something to transmit.\n");
 //fprintf(stderr, ".");
@@ -1121,10 +1146,10 @@ void check_and_transmit_messages(time_t time) {
 
 
     // Skip this function if we did it during this second already.
-    if (last_check_and_transmit == sec_now()) {
+    if (last_check_and_transmit == time) {
         return;
     }
-    last_check_and_transmit = sec_now();
+    last_check_and_transmit = time;
 
     for (i=0; i<MAX_OUTGOING_MESSAGES;i++) {
         if (message_pool[i].active==MESSAGE_ACTIVE) {
@@ -1199,7 +1224,7 @@ void check_and_transmit_messages(time_t time) {
                             //
                             // Change all messages to that callsign
                             // to match the new path.
-                            // 
+                            //
                             change_path_outgoing_messages_to(to_call,new_path);
                         }
 
