@@ -1,9 +1,9 @@
 /*
- * $Id: messages.h,v 1.4 2003/01/24 00:34:51 we7u Exp $
+ * $Id: messages.h,v 1.23 2006/08/28 19:29:52 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2003  The Xastir Group
+ * Copyright (C) 2000-2006  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -35,10 +35,11 @@
 #define MESSAGE_CLEAR 'C'
 
 #define MAX_OUTGOING_MESSAGES 100
-#define MAX_MESSAGE_OUTPUT_LENGTH 64
+#define MAX_MESSAGE_OUTPUT_LENGTH 67
 #define MAX_MESSAGE_ORDER 10
-#define MAX_TRIES 30
-#define MAX_CALLSIGN 20
+
+// Max tries to get a message through
+#define MAX_TRIES 18
 
 typedef struct {
     char active;
@@ -53,7 +54,7 @@ typedef struct {
     int wait_on_first_ack;
 } Message_transmit;
 
-#define MAX_MESSAGE_WINDOWS 10
+#define MAX_MESSAGE_WINDOWS 25
 
 typedef struct {
     char win[10];
@@ -61,12 +62,22 @@ typedef struct {
     int message_group;
     Widget send_message_dialog;
     Widget send_message_call_data;
-    Widget send_message_message_data;
+    Widget D700_mode;
+    Widget D7_mode;
+    Widget HamHUD_mode;
+    Widget message_data_line1;
+    Widget message_data_line2;
+    Widget message_data_line3;
+    Widget message_data_line4;
     Widget send_message_text;
     Widget send_message_path;
+    Widget send_message_reverse_path;
+    Widget send_message_change_path;
     Widget pane, form, button_ok, button_cancel;
-    Widget button_clear_msg, button_submit_call;
-    Widget call, message, path;
+    Widget button_clear_old_msgs, button_submit_call;
+    Widget button_clear_pending_msgs;
+    Widget button_kick_timer;
+    Widget call, message, path, reverse_path_label;
 } Message_Window;
 
 
@@ -74,21 +85,28 @@ extern Widget auto_msg_on, auto_msg_off;
 
 extern int auto_reply;
 extern char auto_reply_message[100];
-extern char group_data_file[];
+extern char group_data_file[400];
 
 extern void clear_acked_message(char *from, char *to, char *seq);
 extern void transmit_message_data(char *to, char *message, char *path);
+extern void transmit_message_data_delayed(char *to, char *message, char *path, time_t when);
+extern void check_delayed_transmit_queue(int curr_sec);
+
+
 //extern void output_message(char *from, char *to, char *message);
 extern int check_popup_window(char *from_call_sign, int group);
 extern int look_for_open_group_data(char *to);
 extern void send_queued(char *to);
-
+extern void clear_outgoing_messages_to(char *callsign);
+extern void change_path_outgoing_messages_to(char *callsign, char *new_path);
 
 /* from messages_gui.c */
 extern xastir_mutex send_message_dialog_lock;
 extern void messages_gui_init(void);
+extern void get_send_message_path(char *callsign, char *path, int path_size);
 extern void Send_message(Widget w, XtPointer clientData, XtPointer callData);
 extern void Clear_messages(Widget w, XtPointer clientData, XtPointer callData);
+void kick_outgoing_timer(char *callsign);
 extern void Send_message_call(Widget w, XtPointer clientData, XtPointer callData);
 
 // view_message_gui.c
