@@ -1,9 +1,9 @@
 /*
- * $Id: popup.h,v 1.4 2005/01/08 09:46:48 we7u Exp $
+ * $Id: popup.h,v 1.7 2006/08/21 13:58:47 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2005  The Xastir Group
+ * Copyright (C) 2000-2006  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -25,7 +25,7 @@
 #ifndef XASTIR_POPUP_H
 #define XASTIR_POPUP_H
 
-#define MAX_POPUPS 20
+#define MAX_POPUPS 30
 #define MAX_POPUPS_TIME 600 /* Max time popups will display 600=10min*/
 
 typedef struct
@@ -41,7 +41,7 @@ typedef struct
 /* from popup_gui.c */
 extern void popup_gui_init(void);
 extern void clear_popup_message_windows(void);
-extern void popup_time_out_check(void);
+extern void popup_time_out_check(int curr_sec);
 
 #endif /* XASTIR_POPUP_H */
 
