@@ -1,9 +1,9 @@
 /*
- * $Id: track_gui.c,v 1.50 2005/10/12 18:33:22 we7u Exp $
+ * $Id: track_gui.c,v 1.60 2006/09/09 00:35:50 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2005  The Xastir Group
+ * Copyright (C) 2000-2006  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,7 +22,10 @@
  * Look at the README for more information on the program.
  */
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif  // HAVE_CONFIG_H
+
 #include "snprintf.h"
 
 #include <stdio.h>
@@ -62,7 +65,7 @@ Widget posit_length_value;
 
 int fetching_findu_trail_now = 0;
 
-int track_station_on;           /* used for tracking stations */
+int track_station_on = 0;       /* used for tracking stations */
 int track_me;
 int track_case;                 /* used for tracking stations */
 int track_match;                /* used for tracking stations */
@@ -85,7 +88,17 @@ void track_gui_init(void)
 {
     init_critical_section( &track_station_dialog_lock );
     init_critical_section( &download_findu_dialog_lock );
-    tracking_station_call[0] = '\0';
+
+    if (temp_tracking_station_call[0] != '\0') {
+        xastir_snprintf(tracking_station_call,
+            sizeof(tracking_station_call),
+            "%s",
+            temp_tracking_station_call);
+        track_station_on = 1;
+    }
+    else {
+        tracking_station_call[0] = '\0';
+    }
 }
 
 
@@ -401,6 +414,7 @@ static void* findu_transfer_thread(void *arg) {
     char *fileimg;
     char *log_filename;
     char **ptrs;
+    char sys_cmd[128];
 
 
     // Get fileimg and log_filename from parameters
@@ -415,6 +429,16 @@ static void* findu_transfer_thread(void *arg) {
 
         // Had trouble getting the file.  Abort.
 
+// We may not be able to do any GUI stuff from multiple
+// threads/processes at the same time.  If that is found to be the
+// case we can write to STDERR instead.
+ 
+        // Dump a message to STDERR
+//        fprintf(stderr,
+//            "%s  %s\n",
+//            langcode("POPEM00035"),
+//            langcode("POPEM00044"));
+
         // Fetch Findu Trail: Failed
         popup_message_always(langcode("POPEM00035"),
             langcode("POPEM00044"));
@@ -425,6 +449,11 @@ static void* findu_transfer_thread(void *arg) {
         return(NULL);
     }
 
+// We need to move this message up to the main thread if possible so
+// that we don't have multiple threads writing to the GUI.  This
+// sort of operation can cause segfaults.  In practice I haven't
+// seen any segfaults due to this particular popup though.
+
     // Fetch Findu Trail: Complete
     popup_message_always(langcode("POPEM00036"),
         langcode("POPEM00045"));
@@ -432,6 +461,18 @@ static void* findu_transfer_thread(void *arg) {
     // Set permissions on the file so that any user can overwrite it.
     chmod(log_filename, 0666);
 
+    // Add three spaces before the "<br" on each line.  This is so
+    // that Base-91 compressed packets with no comment and no
+    // speed/course/altitude will get decoded ok.  Otherwise the
+    // spaces that are critical to the Base-91 packets won't be
+    // there due to findu.com filtering them out.
+    //
+    sprintf(sys_cmd,
+        "sed -i -e \"s/<br>/   <br>/\" %s",
+        log_filename);
+    system(sys_cmd);
+//fprintf(stderr,"%s\n", sys_cmd);
+
     // Here we do the findu stuff, if the findu_flag is set.  Else we do an imagemap.
     // We have the log data we're interested in within the log_filename file.
     // Cause that file to be read by the "File->Open Log File" routine.  HTML
@@ -550,9 +591,19 @@ void Download_trail_now(Widget w, XtPointer clientData, XtPointer callData) {
 // Setting the read_file_ptr to the downloaded file won't do it.
 
 
+
+//        "http://www.findu.com/cgi-bin/rawposit.cgi?call=%s&start=%d&length=%d&time=1", // New, with timestamp
     xastir_snprintf(fileimg, sizeof(fileimg),
-        "http://www.findu.com/cgi-bin/rawposit.cgi?call=%s&start=%d&length=%d",         // Old
-//        "http://www.findu.com/cgi-bin/rawposit.cgi?call=%s&start=%d&length=%d&time=1",// New
+        //
+        // Posits only:
+        // "http://www.findu.com/cgi-bin/rawposit.cgi?call=%s&start=%d&length=%d",
+        //
+        // Posits plus timestamps (we can't handle timestamps yet):
+        // "http://www.findu.com/cgi-bin/rawposit.cgi?call=%s&start=%d&length=%d&time=1", // New, with timestamp
+        // 
+        // Download all packets, not just posits:
+        "http://www.findu.com/cgi-bin/raw.cgi?call=%s&start=%d&length=%d",
+        //
         download_trail_station_call,posit_start,posit_length);
 
     if (debug_level & 1024) {
@@ -615,6 +666,7 @@ void Reset_posit_length_max(Widget w, XtPointer clientData, XtPointer callData)
 void Download_findu_trail( /*@unused@*/ Widget w, /*@unused@*/ XtPointer clientData, /*@unused@*/ XtPointer callData) {
     static Widget pane, my_form, button_ok, button_cancel, call, sep;
     Atom delw;
+    XmString x_str;
 
 
     if (!download_findu_dialog) {
@@ -679,6 +731,7 @@ begin_critical_section(&download_findu_dialog_lock, "track_gui.c:Download_findu_
                 XmNtraversalOn, TRUE,
                 NULL);
 
+        x_str = XmStringCreateLocalized(langcode("WPUPTSP009"));
         posit_start_value = XtVaCreateManagedWidget("Start of Trail (hrs ago)", 
                 xmScaleWidgetClass, 
                 my_form,
@@ -701,11 +754,17 @@ begin_critical_section(&download_findu_dialog_lock, "track_gui.c:Download_findu_
                 XmNmaximum, MAX_FINDU_START_TIME,
                 XmNshowValue, TRUE,
                 XmNvalue, posit_start,
-                XtVaTypedArg, XmNtitleString, XmRString, langcode("WPUPTSP009"), 22,
+// Note:  Some versions of OpenMotif (distributed with Fedora,
+// perhaps others) don't work properly with XtVaTypedArg() as used
+// here, instead showing blank labels for the Scale widgets.
+//                XtVaTypedArg, XmNtitleString, XmRString, langcode("WPUPTSP009"), 22,
+                XmNtitleString, x_str,
                 MY_FOREGROUND_COLOR,
                 MY_BACKGROUND_COLOR,
                 NULL);
+        XmStringFree(x_str);
 
+        x_str = XmStringCreateLocalized(langcode("WPUPTSP010"));
         posit_length_value = XtVaCreateManagedWidget("Length of trail (hrs)", 
                 xmScaleWidgetClass, 
                 my_form,
@@ -728,10 +787,15 @@ begin_critical_section(&download_findu_dialog_lock, "track_gui.c:Download_findu_
                 XmNmaximum, MAX_FINDU_DURATION,
                 XmNshowValue, TRUE,
                 XmNvalue, posit_length,
-                XtVaTypedArg, XmNtitleString, XmRString, langcode("WPUPTSP010"), 19,
+// Note:  Some versions of OpenMotif (distributed with Fedora,
+// perhaps others) don't work properly with XtVaTypedArg() as used
+// here, instead showing blank labels for the Scale widgets.
+//                XtVaTypedArg, XmNtitleString, XmRString, langcode("WPUPTSP010"), 19,
+                XmNtitleString, x_str,
                 MY_FOREGROUND_COLOR,
                 MY_BACKGROUND_COLOR,
                 NULL);
+        XmStringFree(x_str);
 
         sep = XtVaCreateManagedWidget("Download_findu_trail sep", 
                 xmSeparatorGadgetClass,
