@@ -1,9 +1,9 @@
 /*
- * $Id: util.h,v 1.42 2005/10/25 19:25:42 we7u Exp $
+ * $Id: util.h,v 1.48 2006/08/31 21:36:06 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2005  The Xastir Group
+ * Copyright (C) 2000-2006  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -33,7 +33,21 @@
 // Max number of WIDE digipeaters allowed
 #define MAX_WIDES 3
 
+static __inline__ short l16(long val) {
+    // This limits large integer values to the 16 bit range for X
+    // drawing
+    if (val < -32768) val = -32768;
+    if (val >  32767) val =  32767;
+    return (short)val;
+}
 
+static __inline__ unsigned short lu16(long val) {
+    // This limits large unsigned integer values to the 16 bit range
+    // for X drawing
+    if (val < 0) val = 0;
+    if (val > 65535) val = 65535;
+    return (unsigned short)val;
+}
 
 extern int convert_from_xastir_coordinates ( float *f_longitude,
                                       float *f_latitude,
@@ -74,6 +88,12 @@ extern char *compress_posit(const char *lat, const char group, const char *lon,
 extern int  position_defined(long lat, long lon, int strict);
 extern void convert_screen_to_xastir_coordinates(int x, int y, long *lat, long *lon);
 extern void convert_xastir_to_UTM_str(char *str, int str_len, long x, long y);
+extern void convert_xastir_to_MGRS_str_components(char *utmZone, int utmZone_len, 
+                                           char *EastingL, int EastingL_len, 
+                                           char *NorthingL, int NorthingL_len, 
+                                           unsigned int *int_utmEasting, unsigned int *int_utmNorthing, 
+                                           long x,  long y, 
+                                           int nice_format, char *space_string, int space_string_len);
 extern void convert_xastir_to_MGRS_str(char *str, int str_len, long x, long y, int nice_format);
 extern void convert_xastir_to_UTM(double *easting, double *northing, char *zone, int zone_len, long x, long y);
 extern void convert_UTM_to_xastir(double easting, double northing, char *zone, long *x, long *y);
@@ -96,6 +116,7 @@ extern void compute_current_DR_position(DataRow *p_station, long *x_long, long *
 extern int  filethere(char *fn);
 extern int  filecreate(char *fn);
 extern time_t file_time(char *fn);
+extern void load_wx_alerts_from_log(void);
 extern void log_data(char *file, char *line);
 extern void log_tactical_call(char *call_sign, char *tactical_call_sign);
 extern void reload_tactical_calls(void);
@@ -145,7 +166,6 @@ extern int check_unproto_path( char *data );
 
 extern void set_dangerous( char *ptr );
 extern void clear_dangerous(void);
-extern void *rpl_malloc (size_t size);
 
 
 #endif // __XASTIR_UTIL_H
