@@ -1,8 +1,8 @@
 /*
- * $Id: x_spider.c,v 1.46 2005/10/26 19:11:37 we7u Exp $
+ * $Id: x_spider.c,v 1.52 2006/08/18 11:02:55 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
- * Copyright (C) 2003-2005  The Xastir Group
+ * Copyright (C) 2003-2006  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -101,7 +101,10 @@
 // multiplexer, repeater.
 
 
-//#include "config.h"
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif  // HAVE_CONFIG_H
+
 #include "x_spider.h"
 #include "snprintf.h"
 
@@ -440,7 +443,12 @@ return;
         }
 
         // Slow the loop down to prevent excessive CPU.
-        usleep(10000); // 10ms
+
+// NOTE:  We must be faster at processing packets than the
+// main.c:UpdateTime() can send them to us through the pipe!  If
+// we're not, we lose or corrupt packets.
+
+        usleep(1000); // 1ms
     }
 }
 
@@ -720,9 +728,11 @@ int pipe_check(char *client_address) {
     // Check the pipe from Xastir's main thread to see if it is
     // sending us any data
     n = readline(pipe_xastir_to_tcp_server, line, MAXLINE);
+
     if (n == 0) {
         exit(0); // Connection terminated
     }
+
     if (n < 0) {
         //fprintf(stderr,"pipe_check: Readline error: %d\n",errno);
         if (errno == EAGAIN || errno == EWOULDBLOCK) {
@@ -733,20 +743,27 @@ int pipe_check(char *client_address) {
             fprintf(stderr,"pipe_check: Readline error: %d\n",errno);
         }
     }
+
     else {  // We received some data.  Send it down all of the
             // pipes.
 // Also send it down the socket.
         pipe_object *q = pipe_head;
 
+
+//fprintf(stderr,"n:%d\n",n);
+// Terminate it
+line[n] = '\0';
+//fprintf(stderr,"sp %s\n", line);
+ 
         // The internet protocol for sending lines is "\r\n".  Knock
         // off any line-end characters that might be present, then
         // add a "\r\n" combo on the end.
         //
-        if (n > 0 && (line[n-1] == '\r' || line[n-1] == '\n')) {
+        if (line[n-1] == '\r' || line[n-1] == '\n') {
             line[n-1] = '\0';
             n--;
         }
-        if (n > 0 && (line[n-1] == '\r' || line[n-1] == '\n')) {
+        if (line[n-1] == '\r' || line[n-1] == '\n') {
             line[n-1] = '\0';
             n--;
         }
@@ -783,8 +800,10 @@ int pipe_check(char *client_address) {
 /* Globals */
 static char **Argv = ((void *)0);
 #ifdef __linux__
+#ifndef __LSB__
 extern char *__progname, *__progname_full;
-#endif
+#endif  // __LSB__
+#endif  // __linux__
 static char *LastArgv = ((void *)0);
 
 
@@ -818,10 +837,12 @@ void init_set_proc_title(int argc, char *argv[], char *envp[]) {
         LastArgv = envp[i] + strlen(envp[i]);
     }
 #ifdef __linux__
+#ifndef __LSB__
     // Pretty sure you don't need this either
     __progname = strdup("xastir");
     __progname_full = strdup(argv[0]);
-#endif
+#endif  // __LSB__
+#endif  // __linux__
 }
 
 
@@ -903,6 +924,7 @@ void TCP_Server(int argc, char *argv[], char *envp[]) {
     //
     if ( (sockfd = socket(AF_INET, SOCK_STREAM, 0)) < 0) {
         fprintf(stderr,"x_spider: Can't open socket for listening\n");
+        fprintf(stderr,"Could some processes still be running from a previous run of Xastir?\n");
         exit(1);
     }
 
@@ -910,6 +932,7 @@ void TCP_Server(int argc, char *argv[], char *envp[]) {
     //
     if (fcntl(sockfd, F_SETFL, O_NONBLOCK) < 0) {
         fprintf(stderr,"x_spider: Couldn't set socket non-blocking\n");
+        fprintf(stderr,"Could some processes still be running from a previous run of Xastir?\n");
     }
 
     // Set up to reuse the port number (good for debug so we can
@@ -922,6 +945,7 @@ void TCP_Server(int argc, char *argv[], char *envp[]) {
             (char *)&sendbuff,
             sizeof(sendbuff)) < 0) {
         fprintf(stderr,"x_spider: Couldn't set socket REUSEADDR\n");
+        fprintf(stderr,"Could some processes still be running from a previous run of Xastir?\n");
     }
 
     // Bind our local address so that the client can send to us.
@@ -935,6 +959,7 @@ void TCP_Server(int argc, char *argv[], char *envp[]) {
             (struct sockaddr *)&serv_addr,
             sizeof(serv_addr)) < 0) {
         fprintf(stderr,"x_spider: Can't bind local address\n");
+        fprintf(stderr,"Could some processes still be running from a previous run of Xastir?\n");
         exit(1);
     }
 
@@ -987,6 +1012,7 @@ void TCP_Server(int argc, char *argv[], char *envp[]) {
                 // of the loop.
                 //
                 fprintf(stderr,"x_spider: Accept error: %d\n", errno);
+                fprintf(stderr,"Could some processes still be running from a previous run of Xastir?\n");
                 goto finis;
             }
         }
@@ -1121,6 +1147,7 @@ void TCP_Server(int argc, char *argv[], char *envp[]) {
         //
         if (fcntl(p->to_parent[0], F_SETFL, O_NONBLOCK) < 0) {
             fprintf(stderr,"x_spider: Couldn't set read-end of pipe_to_parent non-blocking\n");
+            fprintf(stderr,"Could some processes still be running from a previous run of Xastir?\n");
         }
 
 finis:
@@ -1129,7 +1156,12 @@ finis:
         // pipe_check() function once we get to that stage of
         // coding.
         //
-        usleep(10000); // 10ms
+
+// NOTE:  We must be faster at processing packets than the
+// main.c:UpdateTime() can send them to us through the pipe!  If
+// we're not, we lose or corrupt packets.
+
+        usleep(1000); // 1ms
     }
 }
 
@@ -1160,7 +1192,8 @@ void send_udp_nack(int sock, struct sockaddr_in from, int fromlen) {
 // programs to inject packets into Xastir via UDP protocol.
 //
 void UDP_Server(int argc, char *argv[], char *envp[]) {
-    int sock, length, fromlen, n1, n2;
+    int sock, length, n1, n2;
+    socklen_t fromlen;
     struct sockaddr_in server;
     struct sockaddr_in from;
     char buf[1024];
@@ -1178,6 +1211,7 @@ void UDP_Server(int argc, char *argv[], char *envp[]) {
 
     if (sock < 0) {
         fprintf(stderr, "Error: Opening socket");
+        fprintf(stderr,"Could some processes still be running from a previous run of Xastir?\n");
         return;
     }
 
@@ -1190,6 +1224,7 @@ void UDP_Server(int argc, char *argv[], char *envp[]) {
 
     if (bind(sock, (struct sockaddr *)&server, length) < 0) {
         fprintf(stderr, "Error: Binding");
+        fprintf(stderr,"Could some processes still be running from a previous run of Xastir?\n");
         return;
     }
 
@@ -1200,7 +1235,8 @@ void UDP_Server(int argc, char *argv[], char *envp[]) {
             buf,
             1024,
             0,
-            (struct sockaddr *)&from, &fromlen);
+            (struct sockaddr *)&from,
+            &fromlen);
         if (n1 < 0) {
             fprintf(stderr, "Error: recvfrom");
         }
@@ -1459,6 +1495,7 @@ int Fork_TCP_server(int argc, char *argv[], char *envp[]) {
         //
         if (fcntl(pipe_xastir_to_tcp_server, F_SETFL, O_NONBLOCK) < 0) {
             fprintf(stderr,"x_spider: Couldn't set read-end of pipe_xastir_to_tcp_server non-blocking\n");
+            fprintf(stderr,"Could some processes still be running from a previous run of Xastir?\n");
         }
 
         // Go into an infinite loop here which restarts the
@@ -1488,6 +1525,7 @@ int Fork_TCP_server(int argc, char *argv[], char *envp[]) {
     //
     if (fcntl(pipe_tcp_server_to_xastir, F_SETFL, O_NONBLOCK) < 0) {
         fprintf(stderr,"x_spider: Couldn't set read-end of pipe_tcp_server_to_xastir non-blocking\n");
+        fprintf(stderr,"Could some processes still be running from a previous run of Xastir?\n");
     }
 
 //    // Set write-end of pipe to be non-blocking.
@@ -1604,6 +1642,7 @@ int Fork_UDP_server(int argc, char *argv[], char *envp[]) {
     //
     if (fcntl(pipe_udp_server_to_xastir, F_SETFL, O_NONBLOCK) < 0) {
         fprintf(stderr,"x_spider: Couldn't set read-end of pipe_udp_server_to_xastir non-blocking\n");
+        fprintf(stderr,"Could some processes still be running from a previous run of Xastir?\n");
     }
 
 //    // Set write-end of pipe to be non-blocking.
