@@ -1,9 +1,9 @@
 /* -*- c-basic-offset: 4; indent-tabs-mode: nil -*-
- * $Id: xa_config.c,v 1.148 2005/10/20 21:41:05 we7u Exp $
+ * $Id: xa_config.c,v 1.161 2006/09/19 14:43:46 chicoreus Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2005  The Xastir Group
+ * Copyright (C) 2000-2006  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -63,7 +63,7 @@
 
 #define MAX_VALUE 300
 
-
+//extern char xa_config_dir[];
 
 
 
@@ -136,6 +136,7 @@ void input_close(void)
     the value of that option.
     The return value of the function will be 1 if the option is found and 0
     if the option is not found.
+    May return empty string in "value".
 */
 int get_string(char *option, char *value, int value_size) {
     char config_file[MAX_VALUE];
@@ -264,16 +265,49 @@ char *get_user_base_dir(char *dir) {
     static char base[MAX_VALUE];
     char *env_ptr;
 
-    xastir_snprintf(base,
-        sizeof(base),
-        "%s",
-        ((env_ptr = getenv ("XASTIR_USER_BASE")) != NULL) ? env_ptr : user_dir);
+   // fprintf(stderr,"base: %s \nxa_config_dir: %s\n", base, xa_config_dir);
 
+    switch (xa_config_dir[0]) {
+    case '/':
+	//have some path
+        xastir_snprintf(base, sizeof(base), "%s",xa_config_dir);
+        break; 
+
+    case '\0' : 
+        // build from scratch
+        xastir_snprintf(base,
+            sizeof(base),
+            "%s",
+            ((env_ptr = getenv ("XASTIR_USER_BASE")) != NULL) ? env_ptr : user_dir);
+
+        if (base[strlen (base) - 1] != '/')
+            strncat (base, "/", sizeof(base) - strlen(base));
+
+        strncat (base, ".xastir/", sizeof(base) - strlen(base));
+        break ;
+
+    default: 
+        // Unqualified path
+        xastir_snprintf(base, sizeof(base), "%s",
+            ((env_ptr = getenv ("PWD")) != NULL) ? env_ptr : user_dir);
+
+       	if (base[strlen (base) - 1] != '/')
+            strncat (base, "/", sizeof(base) - strlen(base));
+
+        strncat (base, xa_config_dir, sizeof(base) - strlen(base));
+    }
+    
     if (base[strlen (base) - 1] != '/')
         strncat (base, "/", sizeof(base) - strlen(base));
 
-    strncat (base, ".xastir/", sizeof(base) - strlen(base));
+    // Save base so we monkey around less later. 
+    
+    xastir_snprintf(xa_config_dir,sizeof(xa_config_dir),"%s", base);
+
+    // Append dir and return 
+    
     return strncat(base, dir, sizeof(base) - strlen(base));
+
 }
 
 
@@ -457,6 +491,7 @@ void save_data(void)  {
         store_char (fout, "STATION_MESSAGE_TYPE", aprs_station_message_type);
         store_string (fout, "STATION_POWER", my_phg);
         store_string (fout, "STATION_COMMENTS", my_comment);
+        store_int (fout, "MY_TRAIL_DIFF_COLOR", my_trail_diff_color);
         if (debug_level & 1)
             fprintf(stderr,"Save Data 1\n");
 
@@ -478,8 +513,8 @@ fprintf(stderr,"X:%d  y:%d\n", (int)x_return, (int)y_return);
 */
 
 
-        store_long (fout, "SCREEN_LAT", mid_y_lat_offset);
-        store_long (fout, "SCREEN_LONG", mid_x_long_offset);
+        store_long (fout, "SCREEN_LAT", center_latitude);
+        store_long (fout, "SCREEN_LONG", center_longitude);
 
         store_string(fout, "RELAY_DIGIPEAT_CALLS", relay_digipeater_calls);
 
@@ -525,6 +560,7 @@ fprintf(stderr,"X:%d  y:%d\n", (int)x_return, (int)y_return);
 
         /* maps */
         store_int (fout, "MAPS_LONG_LAT_GRID", long_lat_grid);
+        store_int (fout, "MAPS_LABELED_GRID_BORDER", draw_labeled_grid_border);
         store_int (fout, "MAPS_LEVELS", map_color_levels);
         store_int (fout, "MAPS_LABELS", map_labels);
         store_int (fout, "MAPS_AUTO_MAPS", map_auto_maps);
@@ -536,6 +572,7 @@ fprintf(stderr,"X:%d  y:%d\n", (int)x_return, (int)y_return);
         store_string (fout, "MAPS_LABEL_FONT_MEDIUM", rotated_label_fontname[FONT_MEDIUM]);
         store_string (fout, "MAPS_LABEL_FONT_LARGE", rotated_label_fontname[FONT_LARGE]);
         store_string (fout, "MAPS_LABEL_FONT_HUGE", rotated_label_fontname[FONT_HUGE]);
+        store_string (fout, "MAPS_LABEL_FONT_BORDER", rotated_label_fontname[FONT_BORDER]);
         store_string (fout, "MAPS_LABEL_FONT", rotated_label_fontname[FONT_DEFAULT]);
 //N0VH
 #if defined(HAVE_IMAGEMAGICK)
@@ -842,9 +879,13 @@ fprintf(stderr,"X:%d  y:%d\n", (int)x_return, (int)y_return);
         // LOGGING
         store_int (fout, "LOG_IGATE", log_igate);
         store_int (fout, "LOG_WX", log_wx);
+        store_int (fout, "LOG_MESSAGE", log_message_data);
+        store_int (fout, "LOG_WX_ALERT", log_wx_alert_data);
         store_string (fout, "LOGFILE_IGATE", LOGFILE_IGATE);
         store_string (fout, "LOGFILE_NET", LOGFILE_NET);
         store_string (fout, "LOGFILE_WX", LOGFILE_WX);
+        store_string (fout, "LOGFILE_MESSAGE", LOGFILE_MESSAGE);
+        store_string (fout, "LOGFILE_WX_ALERT", LOGFILE_WX_ALERT);
 
         // SNAPSHOTS
         store_int (fout, "SNAPSHOTS_ENABLED", snapshots_enabled);
@@ -984,6 +1025,7 @@ fprintf(stderr,"X:%d  y:%d\n", (int)x_return, (int)y_return);
         store_int (fout, "TRAIL_SEGMENT_TIME", trail_segment_time);
         store_int (fout, "TRAIL_SEGMENT_DISTANCE", trail_segment_distance);
         store_int (fout, "RINO_DOWNLOAD_INTERVAL", RINO_download_interval);
+        store_int (fout, "SNAPSHOT_INTERVAL", snapshot_interval);
 
 
         if (debug_level & 1)
@@ -1023,21 +1065,27 @@ void load_data_or_default(void) {
     long temp;
 
     /* language */
-    if (!get_string ("LANGUAGE", lang_to_use, sizeof(lang_to_use)))
+    if (!get_string ("LANGUAGE", lang_to_use, sizeof(lang_to_use))
+            || lang_to_use[0] == '\0') {
         xastir_snprintf(lang_to_use,
             sizeof(lang_to_use),
             "English");
+    }
 
     /* my data */
-    if (!get_string ("STATION_CALLSIGN", my_callsign, sizeof(my_callsign)))
+    if (!get_string ("STATION_CALLSIGN", my_callsign, sizeof(my_callsign))
+            || my_callsign[0] == '\0') {
         xastir_snprintf(my_callsign,
             sizeof(my_callsign),
             "NOCALL");
+    }
 
-    if (!get_string ("STATION_LAT", my_lat, sizeof(my_lat)))
+    if (!get_string ("STATION_LAT", my_lat, sizeof(my_lat))
+            || my_lat[0] == '\0') {
         xastir_snprintf(my_lat,
             sizeof(my_lat),
             "0000.000N");
+    }
     if ( (my_lat[4] != '.')
             || (my_lat[8] != 'N' && my_lat[8] != 'S') ) {
         xastir_snprintf(my_lat,
@@ -1050,10 +1098,12 @@ void load_data_or_default(void) {
     convert_lat_l2s (temp, my_lat, sizeof(my_lat), CONVERT_HP_NOSP);
 
 
-    if (!get_string ("STATION_LONG", my_long, sizeof(my_long)))
+    if (!get_string ("STATION_LONG", my_long, sizeof(my_long))
+            || my_long[0] == '\0') {
         xastir_snprintf(my_long,
             sizeof(my_long),
             "00000.000W");
+    }
     if ( (my_long[5] != '.')
             || (my_long[9] != 'W' && my_long[9] != 'E') ) {
         xastir_snprintf(my_long,
@@ -1077,11 +1127,18 @@ void load_data_or_default(void) {
     if (!get_char ("STATION_MESSAGE_TYPE", &aprs_station_message_type))
         aprs_station_message_type = '=';
 
+    // Empty string is ok here.
     if (!get_string ("STATION_POWER", my_phg, sizeof(my_phg)))
         my_phg[0] = '\0';
 
-    if (!get_string ("STATION_COMMENTS", my_comment, sizeof(my_comment)))
+    if (!get_string ("STATION_COMMENTS", my_comment, sizeof(my_comment))
+            || my_comment[0] == '\0') {
         sprintf (my_comment, "XASTIR-%s", XASTIR_SYSTEM);
+    }
+    /* replacing defined MY_TRAIL_DIFF_COLOR from db.c, default 0 matches 
+       default value of MY_TRAIL_DIFF_COLOR to show all mycall-ssids in 
+       the same color.  */
+    my_trail_diff_color = get_int ("MY_TRAIL_DIFF_COLOR", 0, 1, 0);
 
     /* default values */
     screen_width = get_long ("SCREEN_WIDTH", 61l, 10000l, 61l);
@@ -1092,9 +1149,10 @@ void load_data_or_default(void) {
 //    screen_y_offset = (Position)get_int ("SCREEN_Y_OFFSET", 0, 10000, 0);
 
 
-    mid_y_lat_offset = get_long ("SCREEN_LAT", 0l, 64800000l, 32400000l);
-    mid_x_long_offset = get_long ("SCREEN_LONG", 0l, 129600000l, 64800000l);
+    center_latitude = get_long ("SCREEN_LAT", 0l, 64800000l, 32400000l);
+    center_longitude = get_long ("SCREEN_LONG", 0l, 129600000l, 64800000l);
 
+    // Empty string is ok here
     if (!get_string("RELAY_DIGIPEAT_CALLS", relay_digipeater_calls, sizeof(relay_digipeater_calls)))
         sprintf (relay_digipeater_calls, "WIDE1-1");
     // Make them all upper-case.
@@ -1106,7 +1164,7 @@ void load_data_or_default(void) {
 
     scale_y = get_long ("SCREEN_ZOOM", 1l, 500000l, 327680l);
 
-    scale_x = get_x_scale(mid_x_long_offset,mid_y_lat_offset,scale_y);
+    scale_x = get_x_scale(center_longitude,center_latitude,scale_y);
 
     map_background_color = get_int ("MAP_BGCOLOR", 0, 11, 0);
 
@@ -1114,19 +1172,25 @@ void load_data_or_default(void) {
 
 #if !defined(NO_GRAPHICS)
 #if defined(HAVE_IMAGEMAGICK)
-    if (!get_string("IMAGEMAGICK_GAMMA_ADJUST", name, sizeof(name)))
+    if (!get_string("IMAGEMAGICK_GAMMA_ADJUST", name, sizeof(name))
+            || name[0] == '\0') {
         imagemagick_gamma_adjust = 0.0;
-    else
+    }
+    else {
         if (1 != sscanf(name, "%f", &imagemagick_gamma_adjust)) {
             fprintf(stderr,"load_data_or_default:sscanf parsing error\n");
         }
+    }
 #endif  // HAVE_IMAGEMAGICK
-    if (!get_string("RASTER_MAP_INTENSITY", name, sizeof(name)))
+    if (!get_string("RASTER_MAP_INTENSITY", name, sizeof(name))
+            || name[0] == '\0') {
         raster_map_intensity = 1.0;
-    else
+    }
+    else {
         if (1 != sscanf(name, "%f", &raster_map_intensity)) {
             fprintf(stderr,"load_data_or_default:sscanf parsing error\n");
         }
+    }
 #endif  // NO_GRAPHICS
 
     letter_style = get_int ("MAP_LETTERSTYLE", 0, 2, 1);
@@ -1135,6 +1199,7 @@ void load_data_or_default(void) {
 
     wx_alert_style = get_int ("MAP_WX_ALERT_STYLE", 0, 1, 1);
 
+    // Empty string is ok here
     if (!get_string("ALTNET_CALL", altnet_call, sizeof(altnet_call)))
         xastir_snprintf(altnet_call,
             sizeof(altnet_call),
@@ -1144,71 +1209,114 @@ void load_data_or_default(void) {
 
     skip_dupe_checking = get_int("SKIP_DUPE_CHECK", 0, 1, 0);
 
-    if (!get_string ("AUTO_MAP_DIR", AUTO_MAP_DIR, sizeof(AUTO_MAP_DIR)))
+    if (!get_string ("AUTO_MAP_DIR", AUTO_MAP_DIR, sizeof(AUTO_MAP_DIR))
+            || AUTO_MAP_DIR[0] == '\0') {
         xastir_snprintf(AUTO_MAP_DIR,
             sizeof(AUTO_MAP_DIR),
             "%s",
             get_data_base_dir ("maps"));
+    }
 
-    if (!get_string ("ALERT_MAP_DIR", ALERT_MAP_DIR, sizeof(ALERT_MAP_DIR)))
+    if (!get_string ("ALERT_MAP_DIR", ALERT_MAP_DIR, sizeof(ALERT_MAP_DIR))
+            || ALERT_MAP_DIR[0] == '\0') {
         xastir_snprintf(ALERT_MAP_DIR,
             sizeof(ALERT_MAP_DIR),
             "%s",
             get_data_base_dir ("Counties"));
+    }
 
-    if (!get_string ("SELECTED_MAP_DIR", SELECTED_MAP_DIR, sizeof(SELECTED_MAP_DIR)))
+    if (!get_string ("SELECTED_MAP_DIR", SELECTED_MAP_DIR, sizeof(SELECTED_MAP_DIR))
+            || SELECTED_MAP_DIR[0] == '\0') {
         xastir_snprintf(SELECTED_MAP_DIR,
             sizeof(SELECTED_MAP_DIR),
             "%s",
             get_data_base_dir ("maps"));
+    }
 
-    if (!get_string ("SELECTED_MAP_DATA", SELECTED_MAP_DATA, sizeof(SELECTED_MAP_DATA)))
+    if (!get_string ("SELECTED_MAP_DATA", SELECTED_MAP_DATA, sizeof(SELECTED_MAP_DATA))
+            || SELECTED_MAP_DATA[0] == '\0') {
         xastir_snprintf(SELECTED_MAP_DATA,
             sizeof(SELECTED_MAP_DATA),
             "%s",
-            get_user_base_dir ("config/selected_maps.sys"));
+            "config/selected_maps.sys");
+    }
+    // Check for old complete path, change to new short path if a
+    // match
+    if (strncmp( get_user_base_dir(""), SELECTED_MAP_DATA, strlen(get_user_base_dir(""))) == 0)
+         xastir_snprintf(SELECTED_MAP_DATA,
+            sizeof(SELECTED_MAP_DATA),
+            "%s",
+            "config/selected_maps.sys");
 
-    if (!get_string ("MAP_INDEX_DATA", MAP_INDEX_DATA, sizeof(MAP_INDEX_DATA)))
+    if (!get_string ("MAP_INDEX_DATA", MAP_INDEX_DATA, sizeof(MAP_INDEX_DATA))
+            || MAP_INDEX_DATA[0] == '\0') {
         xastir_snprintf(MAP_INDEX_DATA,
             sizeof(MAP_INDEX_DATA),
             "%s",
-            get_user_base_dir ("config/map_index.sys"));
-
-    if (!get_string ("SYMBOLS_DIR", SYMBOLS_DIR, sizeof(SYMBOLS_DIR)))
+            "config/map_index.sys");
+    }
+    // Check for old complete path, change to new short path if a
+    // match
+    if (strncmp( get_user_base_dir(""), MAP_INDEX_DATA, strlen(get_user_base_dir(""))) == 0)
+        xastir_snprintf(MAP_INDEX_DATA,
+            sizeof(MAP_INDEX_DATA),
+            "%s",
+            "config/map_index.sys");
+ 
+    if (!get_string ("SYMBOLS_DIR", SYMBOLS_DIR, sizeof(SYMBOLS_DIR))
+            || SYMBOLS_DIR[0] == '\0') {
         xastir_snprintf(SYMBOLS_DIR,
             sizeof(SYMBOLS_DIR),
             "%s",
             get_data_base_dir ("symbols"));
+    }
 
-    if (!get_string ("SOUND_DIR", SOUND_DIR, sizeof(SOUND_DIR)))
+    if (!get_string ("SOUND_DIR", SOUND_DIR, sizeof(SOUND_DIR))
+            || SOUND_DIR[0] == '\0') {
         xastir_snprintf(SOUND_DIR,
             sizeof(SOUND_DIR),
             "%s",
             get_data_base_dir ("sounds"));
+    }
 
-    if (!get_string ("GROUP_DATA_FILE", group_data_file, sizeof(group_data_file)))
+    if (!get_string ("GROUP_DATA_FILE", group_data_file, sizeof(group_data_file))
+            || group_data_file[0] == '\0') {
         xastir_snprintf(group_data_file,
             sizeof(group_data_file),
             "%s",
-            get_user_base_dir ("config/groups"));
+            "config/groups");
+    }
+    // Check for old complete path, change to new short path if a
+    // match
+    if (strncmp( get_user_base_dir(""), group_data_file, strlen(get_user_base_dir(""))) == 0)
+        xastir_snprintf(group_data_file,
+             sizeof(group_data_file),
+            "%s",
+            "config/groups");
 
-    if (!get_string ("GNIS_FILE", locate_gnis_filename, sizeof(locate_gnis_filename)))
+    if (!get_string ("GNIS_FILE", locate_gnis_filename, sizeof(locate_gnis_filename))
+            || locate_gnis_filename[0] == '\0') {
         xastir_snprintf(locate_gnis_filename,
             sizeof(locate_gnis_filename),
             "%s",
             get_data_base_dir ("GNIS/WA.gnis"));
+    }
 
-    if (!get_string ("GEOCODE_FILE", geocoder_map_filename, sizeof(geocoder_map_filename)))
+    if (!get_string ("GEOCODE_FILE", geocoder_map_filename, sizeof(geocoder_map_filename))
+            || geocoder_map_filename[0] == '\0') {
         xastir_snprintf(geocoder_map_filename,
             sizeof(geocoder_map_filename),
             "%s",
             get_data_base_dir ("GNIS/geocode"));
+    }
 
     show_destination_mark = get_int ("SHOW_FIND_TARGET", 0, 1, 1);
 
     /* maps */
     long_lat_grid = get_int ("MAPS_LONG_LAT_GRID", 0, 1, 1);
 
+    draw_labeled_grid_border = get_int ("MAPS_LABELED_GRID_BORDER", 0, 1, 0);
+
     map_color_levels = get_int ("MAPS_LEVELS", 0, 1, 0);
 
     map_labels = get_int ("MAPS_LABELS", 0, 1, 1);
@@ -1219,39 +1327,58 @@ void load_data_or_default(void) {
 
     index_maps_on_startup = get_int ("MAPS_INDEX_ON_STARTUP", 0, 1, 1);
 
-    if (!get_string ("MAPS_LABEL_FONT_TINY", rotated_label_fontname[FONT_TINY], sizeof(rotated_label_fontname[FONT_TINY])))
+    if (!get_string ("MAPS_LABEL_FONT_TINY", rotated_label_fontname[FONT_TINY], sizeof(rotated_label_fontname[FONT_TINY]))
+            || rotated_label_fontname[FONT_TINY][0] == '\0') {
         xastir_snprintf(rotated_label_fontname[FONT_TINY],
             sizeof(rotated_label_fontname[FONT_TINY]),
             "-adobe-helvetica-medium-r-normal--8-*-*-*-*-*-iso8859-1");
+    }
 
-    if (!get_string ("MAPS_LABEL_FONT_SMALL", rotated_label_fontname[FONT_SMALL], sizeof(rotated_label_fontname[FONT_SMALL])))
+    if (!get_string ("MAPS_LABEL_FONT_SMALL", rotated_label_fontname[FONT_SMALL], sizeof(rotated_label_fontname[FONT_SMALL]))
+            || rotated_label_fontname[FONT_SMALL][0] == '\0') {
         xastir_snprintf(rotated_label_fontname[FONT_SMALL],
             sizeof(rotated_label_fontname[FONT_SMALL]),
             "-adobe-helvetica-medium-r-normal--10-*-*-*-*-*-iso8859-1");
+    }
 
-    if (!get_string ("MAPS_LABEL_FONT_MEDIUM", rotated_label_fontname[FONT_MEDIUM], sizeof(rotated_label_fontname[FONT_MEDIUM])))
+    if (!get_string ("MAPS_LABEL_FONT_MEDIUM", rotated_label_fontname[FONT_MEDIUM], sizeof(rotated_label_fontname[FONT_MEDIUM]))
+            || rotated_label_fontname[FONT_MEDIUM][0] == '\0') {
         xastir_snprintf(rotated_label_fontname[FONT_MEDIUM],
             sizeof(rotated_label_fontname[FONT_MEDIUM]),
             "-adobe-helvetica-medium-r-normal--12-*-*-*-*-*-iso8859-1");
+    }
 
-    if (!get_string ("MAPS_LABEL_FONT_LARGE", rotated_label_fontname[FONT_LARGE], sizeof(rotated_label_fontname[FONT_LARGE])))
+    if (!get_string ("MAPS_LABEL_FONT_LARGE", rotated_label_fontname[FONT_LARGE], sizeof(rotated_label_fontname[FONT_LARGE]))
+            || rotated_label_fontname[FONT_LARGE][0] == '\0') {
         xastir_snprintf(rotated_label_fontname[FONT_LARGE],
             sizeof(rotated_label_fontname[FONT_LARGE]),
             "-adobe-helvetica-medium-r-normal--14-*-*-*-*-*-iso8859-1");
+    }
 
-    if (!get_string ("MAPS_LABEL_FONT_HUGE", rotated_label_fontname[FONT_HUGE], sizeof(rotated_label_fontname[FONT_HUGE])))
+    if (!get_string ("MAPS_LABEL_FONT_HUGE", rotated_label_fontname[FONT_HUGE], sizeof(rotated_label_fontname[FONT_HUGE]))
+            || rotated_label_fontname[FONT_HUGE][0] == '\0') {
         xastir_snprintf(rotated_label_fontname[FONT_HUGE],
             sizeof(rotated_label_fontname[FONT_HUGE]),
             "-adobe-helvetica-medium-r-normal--24-*-*-*-*-*-iso8859-1");
+    }
+    
+    if (!get_string ("MAPS_LABEL_FONT_BORDER", rotated_label_fontname[FONT_BORDER], sizeof(rotated_label_fontname[FONT_BORDER]))
+            || rotated_label_fontname[FONT_BORDER][0] == '\0') {
+        xastir_snprintf(rotated_label_fontname[FONT_BORDER],
+            sizeof(rotated_label_fontname[FONT_BORDER]),
+            "-adobe-helvetica-medium-r-normal--14-*-*-*-*-*-iso8859-1");
+    }
 
-    if (!get_string ("MAPS_LABEL_FONT", rotated_label_fontname[FONT_DEFAULT], sizeof(rotated_label_fontname[FONT_DEFAULT])))
+    if (!get_string ("MAPS_LABEL_FONT", rotated_label_fontname[FONT_DEFAULT], sizeof(rotated_label_fontname[FONT_DEFAULT]))
+            || rotated_label_fontname[FONT_DEFAULT][0] == '\0') {
         xastir_snprintf(rotated_label_fontname[FONT_DEFAULT],
             sizeof(rotated_label_fontname[FONT_DEFAULT]),
-            "-adobe-helvetica-medium-r-normal--12-*-*-*-*-*-iso8859-1");
+            "-adobe-helvetica-bold-r-normal--12-*-*-*-*-*-iso8859-1");
+    }
 
 //N0VH
 #if defined(HAVE_IMAGEMAGICK)
-    net_map_timeout = get_int ("NET_MAP_TIMEOUT", 10, 300, 90);
+    net_map_timeout = get_int ("NET_MAP_TIMEOUT", 10, 300, 120);
 
     tiger_show_grid = get_int ("TIGERMAP_SHOW_GRID", 0, 1, 0);
     tiger_show_counties = get_int ("TIGERMAP_SHOW_COUNTIES", 0, 1, 1);
@@ -1354,6 +1481,7 @@ void load_data_or_default(void) {
             "%s",
             name_temp);
         strncat (name, "NAME", sizeof(name) - strlen(name));
+        // Empty string is ok here.
         if (!get_string (name, devices[i].device_name, sizeof(devices[i].device_name)))
             devices[i].device_name[0] = '\0';
 
@@ -1362,6 +1490,7 @@ void load_data_or_default(void) {
             "%s",
             name_temp);
         strncat (name, "RADIO_PORT", sizeof(name) - strlen(name));
+        // Empty string is ok here.
         if (!get_string (name, devices[i].radio_port, sizeof(devices[i].radio_port)))
             xastir_snprintf(devices[i].radio_port,
                 sizeof(devices[i].radio_port),
@@ -1372,6 +1501,7 @@ void load_data_or_default(void) {
             "%s",
             name_temp);
         strncat (name, "INTERFACE_COMMENT", sizeof(name) - strlen(name));
+        // Empty string is ok here.
         if (!get_string (name, devices[i].comment, sizeof(devices[i].comment)))
             devices[i].comment[0] = '\0';
 
@@ -1380,6 +1510,7 @@ void load_data_or_default(void) {
             "%s",
             name_temp);
         strncat (name, "HOST", sizeof(name) - strlen(name));
+        // Empty string is ok here.
         if (!get_string (name, devices[i].device_host_name, sizeof(devices[i].device_host_name)))
             devices[i].device_host_name[0] = '\0';
 
@@ -1388,6 +1519,7 @@ void load_data_or_default(void) {
             "%s",
             name_temp);
         strncat (name, "PASSWD", sizeof(name) - strlen(name));
+        // Empty string is ok here.
         if (!get_string (name, devices[i].device_host_pswd, sizeof(devices[i].device_host_pswd)))
             devices[i].device_host_pswd[0] = '\0';
 
@@ -1396,6 +1528,7 @@ void load_data_or_default(void) {
             "%s",
             name_temp);
         strncat (name, "FILTER_PARAMS", sizeof(name) - strlen(name));
+        // Empty string is ok here.
         if (!get_string (name, devices[i].device_host_filter_string, sizeof(devices[i].device_host_filter_string)))
             devices[i].device_host_filter_string[0] = '\0';
 
@@ -1404,6 +1537,7 @@ void load_data_or_default(void) {
             "%s",
             name_temp);
         strncat (name, "UNPROTO1", sizeof(name) - strlen(name));
+        // Empty string is ok here.
         if (!get_string (name, devices[i].unproto1, sizeof(devices[i].unproto1)))
             devices[i].unproto1[0] = '\0';
 
@@ -1412,6 +1546,7 @@ void load_data_or_default(void) {
             "%s",
             name_temp);
         strncat (name, "UNPROTO2", sizeof(name) - strlen(name));
+        // Empty string is ok here.
         if (!get_string (name, devices[i].unproto2, sizeof(devices[i].unproto2)))
             devices[i].unproto2[0] = '\0';
 
@@ -1420,6 +1555,7 @@ void load_data_or_default(void) {
             "%s",
             name_temp);
         strncat (name, "UNPROTO3", sizeof(name) - strlen(name));
+        // Empty string is ok here.
         if (!get_string (name, devices[i].unproto3, sizeof(devices[i].unproto3)))
             devices[i].unproto3[0] = '\0';
 
@@ -1428,14 +1564,18 @@ void load_data_or_default(void) {
             "%s",
             name_temp);
         strncat (name, "UNPROTO_IGATE", sizeof(name) - strlen(name));
-        if (!get_string (name, devices[i].unproto_igate, sizeof(devices[i].unproto_igate)))
-            devices[i].unproto_igate[0] = '\0';
+        // Empty string is ok here.
+        if (!get_string (name, devices[i].unproto_igate, sizeof(devices[i].unproto_igate))
+                || devices[i].unproto_igate[0] == '\0') {
+            xastir_snprintf(devices[i].unproto_igate, sizeof(devices[i].unproto_igate), "WIDE2-1");
+        }
 
         xastir_snprintf(name,
             sizeof(name),
             "%s",
             name_temp);
         strncat (name, "TNC_UP_FILE", sizeof(name) - strlen(name));
+        // Empty string is ok here.
         if (!get_string (name, devices[i].tnc_up_file, sizeof(devices[i].tnc_up_file)))
             devices[i].tnc_up_file[0] = '\0';
 
@@ -1444,6 +1584,7 @@ void load_data_or_default(void) {
             "%s",
             name_temp);
         strncat (name, "TNC_DOWN_FILE", sizeof(name) - strlen(name));
+        // Empty string is ok here.
         if (!get_string (name, devices[i].tnc_down_file, sizeof(devices[i].tnc_down_file)))
             devices[i].tnc_down_file[0] = '\0';
 
@@ -1452,6 +1593,7 @@ void load_data_or_default(void) {
             "%s",
             name_temp);
         strncat (name, "TNC_TXDELAY", sizeof(name) - strlen(name));
+        // Empty string is ok here.
         if (!get_string (name, devices[i].txdelay, sizeof(devices[i].txdelay)))
             xastir_snprintf(devices[i].txdelay,
                 sizeof(devices[i].txdelay),
@@ -1462,6 +1604,7 @@ void load_data_or_default(void) {
             "%s",
             name_temp);
         strncat (name, "TNC_PERSISTENCE", sizeof(name) - strlen(name));
+        // Empty string is ok here.
         if (!get_string (name, devices[i].persistence, sizeof(devices[i].persistence)))
             xastir_snprintf(devices[i].persistence,
                 sizeof(devices[i].persistence),
@@ -1472,6 +1615,7 @@ void load_data_or_default(void) {
             "%s",
             name_temp);
         strncat (name, "TNC_SLOTTIME", sizeof(name) - strlen(name));
+        // Empty string is ok here.
         if (!get_string (name, devices[i].slottime, sizeof(devices[i].slottime)))
             xastir_snprintf(devices[i].slottime,
                 sizeof(devices[i].slottime),
@@ -1482,6 +1626,7 @@ void load_data_or_default(void) {
             "%s",
             name_temp);
         strncat (name, "TNC_TXTAIL", sizeof(name) - strlen(name));
+        // Empty string is ok here.
         if (!get_string (name, devices[i].txtail, sizeof(devices[i].txtail)))
             xastir_snprintf(devices[i].txtail,
                 sizeof(devices[i].txtail),
@@ -1568,11 +1713,20 @@ void load_data_or_default(void) {
     /* TNC */
     log_tnc_data = get_int ("TNC_LOG_DATA", 0,1,0);
 
-    if (!get_string ("LOGFILE_TNC", LOGFILE_TNC, sizeof(LOGFILE_TNC)))
+    if (!get_string ("LOGFILE_TNC", LOGFILE_TNC, sizeof(LOGFILE_TNC))
+            || LOGFILE_TNC[0] == '\0') {
         xastir_snprintf(LOGFILE_TNC,
             sizeof(LOGFILE_TNC),
             "%s",
-            get_user_base_dir ("logs/tnc.log"));
+            "logs/tnc.log");
+    }
+    // Check for old complete path, change to new short path if a
+    // match
+    if (strncmp( get_user_base_dir(""), LOGFILE_TNC, strlen(get_user_base_dir(""))) == 0)
+         xastir_snprintf(LOGFILE_TNC,
+            sizeof(LOGFILE_TNC),
+            "%s",
+            "logs/tnc.log");
 
     /* NET */
     log_net_data = get_int ("NET_LOG_DATA", 0,1,0);
@@ -1585,25 +1739,84 @@ void load_data_or_default(void) {
 
     // LOGGING
     log_wx = get_int ("LOG_WX", 0,1,0);
+    log_message_data = get_int ("LOG_MESSAGE", 0, 1, 0);
+    log_wx_alert_data = get_int ("LOG_WX_ALERT", 0, 1, 0);
 
-    if (!get_string ("LOGFILE_IGATE", LOGFILE_IGATE, sizeof(LOGFILE_IGATE)))
+    if (!get_string ("LOGFILE_IGATE", LOGFILE_IGATE, sizeof(LOGFILE_IGATE))
+            || LOGFILE_IGATE[0] == '\0') {
         xastir_snprintf(LOGFILE_IGATE,
             sizeof(LOGFILE_IGATE),
             "%s",
-            get_user_base_dir ("logs/igate.log"));
+            "logs/igate.log");
+    }
+    // Check for old complete path, change to new short path if a
+    // match
+    if (strncmp( get_user_base_dir(""), LOGFILE_IGATE, strlen(get_user_base_dir(""))) == 0)
+         xastir_snprintf(LOGFILE_IGATE,
+            sizeof(LOGFILE_IGATE),
+            "%s",
+            "logs/igate.log");
 
-    if (!get_string ("LOGFILE_NET", LOGFILE_NET, sizeof(LOGFILE_NET)))
+    if (!get_string ("LOGFILE_NET", LOGFILE_NET, sizeof(LOGFILE_NET))
+            || LOGFILE_NET[0] == '\0') {
         xastir_snprintf(LOGFILE_NET,
             sizeof(LOGFILE_NET),
             "%s",
-            get_user_base_dir ("logs/net.log"));
-
-    if (!get_string ("LOGFILE_WX", LOGFILE_WX, sizeof(LOGFILE_WX)))
+            "logs/net.log");
+    }
+    // Check for old complete path, change to new short path if a
+    // match
+    if (strncmp( get_user_base_dir(""), LOGFILE_NET, strlen(get_user_base_dir(""))) == 0)
+        xastir_snprintf(LOGFILE_NET,
+            sizeof(LOGFILE_NET),
+            "%s",
+            "logs/net.log");
+  
+    if (!get_string ("LOGFILE_WX", LOGFILE_WX, sizeof(LOGFILE_WX))
+            || LOGFILE_WX[0] == '\0') {
         xastir_snprintf(LOGFILE_WX,
             sizeof(LOGFILE_WX),
             "%s",
-            get_user_base_dir ("logs/wx.log"));
+            "logs/wx.log");
+    }
+    // Check for old complete path, change to new short path if a
+    // match
+    if (strncmp( get_user_base_dir(""), LOGFILE_WX, strlen(get_user_base_dir(""))) == 0)
+        xastir_snprintf(LOGFILE_WX,
+            sizeof(LOGFILE_WX),
+            "%s",
+            "logs/wx.log");
 
+    if (!get_string ("LOGFILE_MESSAGE", LOGFILE_MESSAGE, sizeof(LOGFILE_MESSAGE))
+            || LOGFILE_MESSAGE[0] == '\0') {
+        xastir_snprintf(LOGFILE_MESSAGE,
+            sizeof(LOGFILE_MESSAGE),
+            "%s",
+            "logs/message.log");
+    }
+    // Check for old complete path, change to new short path if a
+    // match
+    if (strncmp( get_user_base_dir(""), LOGFILE_MESSAGE, strlen(get_user_base_dir(""))) == 0)
+        xastir_snprintf(LOGFILE_MESSAGE,
+            sizeof(LOGFILE_MESSAGE),
+            "%s",
+            "logs/message.log");
+ 
+    if (!get_string ("LOGFILE_WX_ALERT", LOGFILE_WX_ALERT, sizeof(LOGFILE_WX_ALERT))
+            || LOGFILE_WX_ALERT[0] == '\0') {
+        xastir_snprintf(LOGFILE_WX_ALERT,
+            sizeof(LOGFILE_WX_ALERT),
+            "%s",
+            "logs/wx_alert.log");
+    }
+    // Check for old complete path, change to new short path if a
+    // match
+    if (strncmp( get_user_base_dir(""), LOGFILE_WX_ALERT, strlen(get_user_base_dir(""))) == 0)
+        xastir_snprintf(LOGFILE_WX_ALERT,
+            sizeof(LOGFILE_WX_ALERT),
+            "%s",
+            "logs/wx_alert.log");
+  
     // SNAPSHOTS
     snapshots_enabled = get_int ("SNAPSHOTS_ENABLED", 0,1,0);
 
@@ -1652,6 +1865,7 @@ void load_data_or_default(void) {
 
 
     /* Audio Alarms*/
+    // Empty string is ok here.
     if (!get_string ("SOUND_COMMAND", sound_command, sizeof(sound_command)))
         xastir_snprintf(sound_command,
             sizeof(sound_command),
@@ -1659,58 +1873,76 @@ void load_data_or_default(void) {
 
     sound_play_new_station = get_int ("SOUND_PLAY_ONS", 0,1,0);
 
-    if (!get_string ("SOUND_ONS_FILE", sound_new_station, sizeof(sound_new_station)))
+    if (!get_string ("SOUND_ONS_FILE", sound_new_station, sizeof(sound_new_station))
+            || sound_new_station[0] == '\0') {
         xastir_snprintf(sound_new_station,
             sizeof(sound_new_station),
             "newstation.wav");
+    }
 
     sound_play_new_message = get_int ("SOUND_PLAY_ONM", 0,1,0);
 
-    if (!get_string ("SOUND_ONM_FILE", sound_new_message, sizeof(sound_new_message)))
+    if (!get_string ("SOUND_ONM_FILE", sound_new_message, sizeof(sound_new_message))
+            || sound_new_message[0] == '\0') {
         xastir_snprintf(sound_new_message,
             sizeof(sound_new_message),
             "newmessage.wav");
+    }
 
     sound_play_prox_message = get_int ("SOUND_PLAY_PROX", 0,1,0);
 
-    if (!get_string ("SOUND_PROX_FILE", sound_prox_message, sizeof(sound_prox_message)))
+    if (!get_string ("SOUND_PROX_FILE", sound_prox_message, sizeof(sound_prox_message))
+            || sound_prox_message[0] == '\0') {
         xastir_snprintf(sound_prox_message,
             sizeof(sound_prox_message),
             "proxwarn.wav");
+    }
 
-    if (!get_string ("PROX_MIN", prox_min, sizeof(prox_min)))
+    if (!get_string ("PROX_MIN", prox_min, sizeof(prox_min))
+            || prox_min[0] == '\0') {
         xastir_snprintf(prox_min,
             sizeof(prox_min),
             "0.01");
+    }
 
-    if (!get_string ("PROX_MAX", prox_max, sizeof(prox_max)))
+    if (!get_string ("PROX_MAX", prox_max, sizeof(prox_max))
+            || prox_max[0] == '\0') {
         xastir_snprintf(prox_max,
             sizeof(prox_max),
             "10");
+    }
 
     sound_play_band_open_message = get_int ("SOUND_PLAY_BAND", 0,1,0);
 
-    if (!get_string ("SOUND_BAND_FILE", sound_band_open_message, sizeof(sound_band_open_message)))
+    if (!get_string ("SOUND_BAND_FILE", sound_band_open_message, sizeof(sound_band_open_message))
+            || sound_band_open_message[0] == '\0') {
         xastir_snprintf(sound_band_open_message,
             sizeof(sound_band_open_message),
             "bandopen.wav");
+    }
 
-    if (!get_string ("BANDO_MIN", bando_min, sizeof(bando_min)))
+    if (!get_string ("BANDO_MIN", bando_min, sizeof(bando_min))
+            || bando_min[0] == '\0') {
         xastir_snprintf(bando_min,
             sizeof(bando_min),
             "200");
+    }
 
-    if (!get_string ("BANDO_MAX", bando_max, sizeof(bando_max)))
+    if (!get_string ("BANDO_MAX", bando_max, sizeof(bando_max))
+            || bando_max[0] == '\0') {
         xastir_snprintf(bando_max,
             sizeof(bando_max),
             "2000");
+    }
 
     sound_play_wx_alert_message = get_int ("SOUND_PLAY_WX_ALERT", 0,1,0);
 
-    if (!get_string ("SOUND_WX_ALERT_FILE", sound_wx_alert_message, sizeof(sound_wx_alert_message)))
+    if (!get_string ("SOUND_WX_ALERT_FILE", sound_wx_alert_message, sizeof(sound_wx_alert_message))
+            || sound_wx_alert_message[0] == '\0') {
         xastir_snprintf(sound_wx_alert_message,
             sizeof(sound_wx_alert_message),
             "thunder.wav");
+    }
 
 #ifdef HAVE_FESTIVAL
     /* Festival Speech defaults */
@@ -1733,10 +1965,12 @@ void load_data_or_default(void) {
 
     sec_remove = get_long("DEFAULT_STATION_REMOVE", 1l, 604800*2, sec_clear*2);
 
-    if (!get_string ("MESSAGE_COUNTER", message_counter, sizeof(message_counter)))
+    if (!get_string ("MESSAGE_COUNTER", message_counter, sizeof(message_counter))
+            || message_counter[0] == '\0') {
         xastir_snprintf(message_counter,
             sizeof(message_counter),
             "00");
+    }
 
     message_counter[2] = '\0';  // Terminate at 2 chars
     // Check that chars are within the correct ranges
@@ -1752,10 +1986,12 @@ void load_data_or_default(void) {
         message_counter[1] = '0'; 
     }
 
-    if (!get_string ("AUTO_MSG_REPLY", auto_reply_message, sizeof(auto_reply_message)))
+    if (!get_string ("AUTO_MSG_REPLY", auto_reply_message, sizeof(auto_reply_message))
+        || auto_reply_message[0] == '\0') {
         xastir_snprintf(auto_reply_message,
             sizeof(auto_reply_message),
             "Autoreply- No one is at the keyboard");
+    }
 
     Display_packet_data_type = get_int ("DISPLAY_PACKET_TYPE", 0,2,0);
 
@@ -1765,10 +2001,12 @@ void load_data_or_default(void) {
 
     view_message_limit = get_int("VIEW_MESSAGE_LIMIT", 10000,99999,10000);
     predefined_menu_from_file = get_int("PREDEF_MENU_LOAD",0,1,0);
-    if (!get_string ("PREDEF_MENU_FILE", predefined_object_definition_filename, sizeof(predefined_object_definition_filename)))
+    if (!get_string ("PREDEF_MENU_FILE", predefined_object_definition_filename, sizeof(predefined_object_definition_filename))
+            || predefined_object_definition_filename[0] == '\0') {
         xastir_snprintf(predefined_object_definition_filename,
             sizeof(predefined_object_definition_filename),
             "predefined_SAR.sys");
+    }
 
 
     /* printer variables */
@@ -1823,6 +2061,9 @@ void load_data_or_default(void) {
     // 0 minutes default (function disabled)
     RINO_download_interval = get_int ("RINO_DOWNLOAD_INTERVAL", 0,30,0);
 
+    // 5 minutes default
+    snapshot_interval = get_int ("SNAPSHOT_INTERVAL", 1,30,5);
+
     input_close();
 }
 
